@@ -1,5 +1,5 @@
 /*
- * $Id: AnimatedRendererDemo.java,v 1.4 2008/12/23 18:12:39 kschaefe Exp $
+ * $Id: AnimatedRendererDemo.java 3471 2009-08-27 13:10:39Z kleopatra $
  *
  * Copyright 2006 Sun Microsystems, Inc., 4150 Network Circle,
  * Santa Clara, California 95054, U.S.A. All rights reserved.
@@ -125,9 +125,9 @@ public final class AnimatedRendererDemo {
         table.addHighlighter(stars);
         list.addHighlighter(stars);
         list.setRolloverEnabled(true);
-        final RelativePainter silver = (RelativePainter) silverHL.getPainter();
+        final RelativePainter<?> silver = (RelativePainter<?>) silverHL.getPainter();
         silver.setXFactor(1.);
-        final RelativePainter gold = (RelativePainter) goldHL.getPainter();
+        final RelativePainter<?> gold = (RelativePainter<?>) goldHL.getPainter();
         gold.setXFactor(1.0);
         ActionListener l = new ActionListener() {
             public void actionPerformed(ActionEvent e) {
@@ -145,7 +145,7 @@ public final class AnimatedRendererDemo {
     private PainterHighlighter getRangeHighlighter(String gifName, int start,
             int end) {
         HighlightPredicate meritPredicate = getRangePredicate(start, end);
-        Painter<Component> bronze = getImagePainter(gifName);
+        Painter<? super Component> bronze = getImagePainter(gifName);
         PainterHighlighter painterHighlighter = new PainterHighlighter(meritPredicate, 
                 new RelativePainter<Component>(bronze));
         return painterHighlighter;
@@ -210,8 +210,8 @@ public final class AnimatedRendererDemo {
      * @param string
      * @return
      */
-    private Painter<Component> getImagePainter(String string) {
-        ImagePainter<Component> imagePainter = null;
+    private Painter<? super Component> getImagePainter(String string) {
+        ImagePainter imagePainter = null;
         BufferedImage image = null;
         try {
             image = ImageIO.read(getClass()
@@ -221,10 +221,17 @@ public final class AnimatedRendererDemo {
                       image.getWidth(), 
                       image.getHeight());
             Graphics2D g = mod.createGraphics();
-            g.setComposite(AlphaComposite.getInstance(AlphaComposite.SRC_OVER, 0.8f));
-            g.drawImage(image, 0, 0, image.getWidth(), image.getHeight(), null);
-            g.dispose();
-            imagePainter = new ImagePainter<Component>(mod);
+            
+            try {
+                g.setComposite(AlphaComposite.getInstance(
+                        AlphaComposite.SRC_OVER, 0.8f));
+                g.drawImage(image, 0, 0, image.getWidth(), image.getHeight(),
+                        null);
+            } finally {
+                g.dispose();
+            }
+            
+            imagePainter = new ImagePainter(mod);
             imagePainter.setHorizontalAlignment(HorizontalAlignment.RIGHT);
         } catch (IOException e) {
             // TODO Auto-generated catch block
@@ -372,7 +379,7 @@ public final class AnimatedRendererDemo {
     
     public static class RelativePainter<T> extends AbstractLayoutPainter<T> {
 
-        private Painter<T> painter;
+        private Painter<? super T> painter;
         private double xFactor;
         private double yFactor;
 
@@ -380,18 +387,18 @@ public final class AnimatedRendererDemo {
             this(null);
         }
         
-        public RelativePainter(Painter<T> delegate) {
+        public RelativePainter(Painter<? super T> delegate) {
             setPainter(delegate);
         }
         
         
-        public void setPainter(Painter<T> painter) {
+        public void setPainter(Painter<? super T> painter) {
             Object old = getPainter();
             this.painter = painter;
             firePropertyChange("painter", old, getPainter());
         }
         
-        public Painter<T> getPainter() {
+        public Painter<? super T> getPainter() {
             return painter;
         }
         public void setXFactor(double xPercent) {
