@@ -1,5 +1,5 @@
 /*
- * $Id: SimpleRendererDemo.java,v 1.13 2008/12/23 18:12:39 kschaefe Exp $
+ * $Id: SimpleRendererDemo.java 3471 2009-08-27 13:10:39Z kleopatra $
  *
  * Copyright 2006 Sun Microsystems, Inc., 4150 Network Circle,
  * Santa Clara, California 95054, U.S.A. All rights reserved.
@@ -252,9 +252,16 @@ public final class SimpleRendererDemo {
                       image.getWidth(), 
                       image.getHeight());
             Graphics2D g = mod.createGraphics();
-            g.setComposite(AlphaComposite.getInstance(AlphaComposite.SRC_OVER, 0.8f));
-            g.drawImage(image, 0, 0, image.getWidth(), image.getHeight(), null);
-            g.dispose();
+            
+            try {
+                g.setComposite(AlphaComposite.getInstance(
+                        AlphaComposite.SRC_OVER, 0.8f));
+                g.drawImage(image, 0, 0, image.getWidth(), image.getHeight(),
+                        null);
+            } finally {
+                g.dispose();
+            }
+            
             imagePainter = new ImagePainter(mod);
             imagePainter.setHorizontalAlignment(HorizontalAlignment.LEFT);
         } catch (IOException e) {
@@ -363,7 +370,7 @@ public final class SimpleRendererDemo {
         }
     }
     
-    public static class Contributor implements Comparable {
+    public static class Contributor implements Comparable<Object> {
         private String firstName;
         private String lastName;
         @SuppressWarnings("unused")
@@ -419,6 +426,7 @@ public final class SimpleRendererDemo {
     /**
      * 
      */
+    @SuppressWarnings("unused")
     private static void initLF() {
         try {
             UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
