@@ -1,5 +1,5 @@
 /*
- * $Id: JXCollapsiblePane.java,v 1.28 2008/10/14 22:32:50 rah003 Exp $
+ * $Id: JXCollapsiblePane.java 3518 2009-09-27 04:05:40Z kschaefe $
  *
  * Copyright 2004 Sun Microsystems, Inc., 4150 Network Circle,
  * Santa Clara, California 95054, U.S.A. All rights reserved.
@@ -33,6 +33,7 @@ import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
 
 import javax.swing.AbstractAction;
+import javax.swing.CellRendererPane;
 import javax.swing.JComponent;
 import javax.swing.JPanel;
 import javax.swing.JViewport;
@@ -457,6 +458,21 @@ public class JXCollapsiblePane extends JXPanel {
     public void setAnimated(boolean animated) {
         if (animated != useAnimation) {
             useAnimation = animated;
+            
+            if (!animated) {
+            	if (animateTimer.isRunning()) {
+            		//TODO should we listen for animation state change?
+            		//yes, but we're best off creating a UI delegate for these changes
+            		SwingUtilities.invokeLater(new Runnable() {
+						@Override
+						public void run() {
+							currentDimension = -1;
+						}
+					});
+            	} else {
+            		currentDimension = -1;
+            	}
+            }
             firePropertyChange("animated", !useAnimation, useAnimation);
         }
     }
@@ -501,8 +517,8 @@ public class JXCollapsiblePane extends JXPanel {
     }
     
     /**
-     * @see #setOrientation(Orientation)
-     * @return the current {@link Orientation}
+     * @return the current {@link Direction}.
+     * @see #setDirection(Direction)
      */
     public Direction getDirection() {
         return direction;
@@ -557,10 +573,12 @@ public class JXCollapsiblePane extends JXPanel {
 
                     setAnimationParams(new AnimationParams(30, delta, 0.01f, 1.0f));
                     animator.reinit(dimension, preferredDimension);
+                    wrapper.getView().setVisible(true);
                     animateTimer.start();
                 }
             } else {
                 wrapper.collapsedState = collapsed;
+                wrapper.getView().setVisible(!collapsed);
                 revalidate();
             }
             repaint();
@@ -571,6 +589,7 @@ public class JXCollapsiblePane extends JXPanel {
     /**
      * {@inheritDoc}
      */
+    @Override
     public Border getBorder() {
         if (getContentPane() instanceof JComponent) {
             return ((JComponent) getContentPane()).getBorder();
@@ -582,20 +601,38 @@ public class JXCollapsiblePane extends JXPanel {
     /**
      * {@inheritDoc}
      */
+    @Override
     public void setBorder(Border border) {
         if (getContentPane() instanceof JComponent) {
             ((JComponent) getContentPane()).setBorder(border);
         }
     }
-    
+
     /**
-     * {@inheritDoc}
+     * A collapsible pane always returns its preferred size for the minimum size
+     * to ensure that the collapsing happens correctly.
+     * <p>
+     * To query the minimum size of the contents user {@code
+     * getContentPane().getMinimumSize()}.
+     * 
+     * @return the preferred size of the component
      */
     @Override
     public Dimension getMinimumSize() {
         return getPreferredSize();
     }
 
+    /**
+     * Forwards to the content pane.
+     * 
+     * @param minimumSize
+     *            the size to set on the content pane
+     */
+    @Override
+    public void setMinimumSize(Dimension minimumSize) {
+        getContentPane().setMinimumSize(minimumSize);
+    }
+
     /**
      * The critical part of the animation of this <code>JXCollapsiblePane</code>
      * relies on the calculation of its preferred size. During the animation, its
@@ -752,6 +789,7 @@ public class JXCollapsiblePane extends JXPanel {
                         return;
                     } else {
                         wrapper.collapsedState = true;
+                        wrapper.getView().setVisible(false);
                         JXCollapsiblePane.this.firePropertyChange(ANIMATION_STATE_KEY, null,
                                                                   "collapsed");
                     }
@@ -900,6 +938,21 @@ public class JXCollapsiblePane extends JXPanel {
                 ((JComponent) c).setOpaque(true);
             }
         }
+
+        /**
+         * {@inheritDoc} <p>
+         * 
+         * Overridden to not have JViewPort behaviour (that is scroll the view)
+         * but delegate to parent scrollRectToVisible just a JComponent does.<p>
+         */
+        @Override
+        public void scrollRectToVisible(Rectangle aRect) {
+        	//avoids JViewport's implementation
+        	//by using JXCollapsiblePane's it will delegate upward
+        	//getting any core fixes, by avoiding c&p
+        	JXCollapsiblePane.this.scrollRectToVisible(aRect);
+        }
+        
     }
 
 // TEST CASE
