@@ -1,5 +1,5 @@
 /*
- * $Id: JXDatePicker.java,v 1.91 2008/09/17 16:22:37 kleopatra Exp $
+ * $Id: JXDatePicker.java 3497 2009-09-09 13:42:32Z kleopatra $
  *
  * Copyright 2004 Sun Microsystems, Inc., 4150 Network Circle,
  * Santa Clara, California 95054, U.S.A. All rights reserved.
@@ -52,9 +52,11 @@ import javax.swing.JComponent;
 import javax.swing.JFormattedTextField;
 import javax.swing.JPanel;
 import javax.swing.JPopupMenu;
+import javax.swing.SwingUtilities;
 import javax.swing.UIManager;
 import javax.swing.JFormattedTextField.AbstractFormatter;
 import javax.swing.JFormattedTextField.AbstractFormatterFactory;
+import javax.swing.event.PopupMenuListener;
 import javax.swing.text.DefaultFormatterFactory;
 
 import org.jdesktop.swingx.calendar.DatePickerFormatter;
@@ -106,6 +108,23 @@ import org.jdesktop.swingx.util.Contract;
  * };
  * picker.addActionListener(l);
  * </code></pre>
+ * 
+ * Note that  ActionListener will <b>not</b> be notified if the user 
+ * edits the date text without hitting the Enter key afterwards. To detect both kinds of
+ * date change, interested client code can add a PropertyChangeListener.
+ * 
+ * <pre><code>
+ * JXDatePicker picker = new JXDatePicker(new Date());
+ * PropertyChangeListener listener = new PropertyChangeListener() {
+ *     public void propertyChange(PropertyChangeEvent e) {
+ *         if ("date".equals(e.getPropertyName()) {
+ *              saveDate(picker.getDate());
+ *         }
+ *     }
+ * };
+ * picker.addPropertyChangeListener(listener);
+ * </code></pre>
+
  * 
  * <p>
  * The DateFormats used in the JXDatePicker's are initialized to the default
@@ -124,6 +143,19 @@ import org.jdesktop.swingx.util.Contract;
  * binding to a property of a custom bean when using a binding framework.
  * <p>
  * 
+ * Keybindings (as installed by the UI-Delegate)
+ * <ul>
+ * <li> ENTER commits the edited or selected value
+ * <li> ESCAPE reverts the edited or selected value
+ * <li> alt-DOWN opens the monthView popup
+ * <li> shift-F5 if monthView is visible, navigates the monthView to today 
+ *    (no effect otherwise)
+ * <li> F5 commits today 
+ * </ul>
+ * 
+ * PENDNG JW: support per-OS keybindings to be installed, currently they are 
+ * hardcoded in our (single) BasicDatePickerUI. 
+ * 
  * @author Joshua Outwater
  * @author Jeanette Winzenburg
  * 
@@ -147,9 +179,7 @@ public class JXDatePicker extends JComponent {
 
     public static final String EDITOR = "editor";
     public static final String MONTH_VIEW = "monthView";
-    /** @deprecated pre-0.9.4 no longer used - all "millis" are replaced by date */ 
-    @Deprecated
-    public static final String DATE_IN_MILLIS = "dateInMillis";
+
     public static final String LINK_PANEL = "linkPanel";
 
     /** action command used for commit actionEvent. */
@@ -178,6 +208,7 @@ public class JXDatePicker extends JComponent {
     
     private JXMonthView _monthView;
     private boolean editable = true;
+    // PENDING JW: remove - duplication, we have access to super's listenerlist
     private EventListenerMap listenerMap;
     protected boolean lightWeightPopupEnabled = JPopupMenu.getDefaultLightWeightPopupEnabled();
 
@@ -395,9 +426,8 @@ public class JXDatePicker extends JComponent {
     public void updateUI() {
         setUI((DatePickerUI) LookAndFeelAddons.getUI(this, DatePickerUI.class));
         // JW: quick hack around #706-swingx - monthView not updated
-        // not sure if this here is the correct place nor 
-        // the correct method - SwingUtilities.updateComponentTree might be better
-        getMonthView().updateUI();
+        // is this complete? how about editor (if not uiResource), linkPanel?
+        SwingUtilities.updateComponentTreeUI(getMonthView());
         invalidate();
     }
 
@@ -817,6 +847,7 @@ public class JXDatePicker extends JComponent {
      * @param height Height of the component to determine baseline for.
      * @return baseline for the specified component
      */
+    @Override
     public int getBaseline(int width, int height) {
         return ((DatePickerUI) ui).getBaseline(width, height);
     }
@@ -877,6 +908,38 @@ public class JXDatePicker extends JComponent {
         }
     }
  
+    /**
+     * Adds a PopupMenuListener.<p>
+     * 
+     * PENDING JW: the canceled method is never called due to internal 
+     * interference in BasicDatePickerUI. Probably need to re-visit that. 
+     * 
+     * @param l the PopupMenuListener to add.
+     */
+    public void addPopupMenuListener(PopupMenuListener l) {
+        listenerMap.add(PopupMenuListener.class, l);
+    }
+    
+    /**
+     * Removes a PopupMenuListener.
+     * 
+     * @param l the PopupMenuListener to remove.
+     */
+    public void removePopupMenuListener(PopupMenuListener l) {
+        listenerMap.remove(PopupMenuListener.class, l);
+    }
+    
+    /**
+     * Returns an array containing all PopupMenuListeners which are 
+     * registered to this picker.
+     * 
+     * @return an array containing all PopupMenuListeners which are
+     * registered to this picker, guaranteed to be never null.
+     */
+    public PopupMenuListener[] getPopupMenuListeners() {
+        return getListeners(PopupMenuListener.class);
+    }
+    
     /**
      * Pes: added setLocale method to refresh link text on locale changes
      */
