@@ -1,5 +1,5 @@
 /*
- * $Id: JXGraph.java,v 1.8 2007/03/14 19:46:25 joshy Exp $
+ * $Id: JXGraph.java 3471 2009-08-27 13:10:39Z kleopatra $
  *
  * Copyright 2006 Sun Microsystems, Inc., 4150 Network Circle,
  * Santa Clara, California 95054, U.S.A. All rights reserved.
@@ -46,6 +46,7 @@ import java.text.DecimalFormat;
 import java.text.NumberFormat;
 import java.util.LinkedList;
 import java.util.List;
+
 import org.jdesktop.beans.AbstractBean;
 import org.jdesktop.swingx.painter.Painter;
 
@@ -1000,7 +1001,7 @@ public class JXGraph extends JXPanel {
      *   <li><i>maxX</i>: bounds.getMaxY() (minY + bounds.getHeight())</li>
      * </ul>
      *
-     * <p>If the specificed view is null, nothing happens.</p>
+     * <p>If the specified view is null, nothing happens.</p>
      *
      * <p>Calling this method leaves the origin intact.</p>
      *
@@ -1012,7 +1013,7 @@ public class JXGraph extends JXPanel {
         if (bounds == null) {
             return;
         }
-
+        Rectangle2D old = getView();
         defaultView = new Rectangle2D.Double(bounds.getX(), bounds.getY(),
             bounds.getWidth(), bounds.getHeight());
                 
@@ -1023,7 +1024,7 @@ public class JXGraph extends JXPanel {
         
         majorX = defaultMajorX;
         majorY = defaultMajorY;
-        
+        firePropertyChange("view", old, getView());
         repaint();
     }
 
@@ -1064,7 +1065,7 @@ public class JXGraph extends JXPanel {
      * <p>Sets the origin of the graph. The coordinates of the origin are
      * defined by the coordinates of the point passed as parameter.</p>
      *
-     * <p>If the specificed view is null, nothing happens.</p>
+     * <p>If the specified view is null, nothing happens.</p>
      *
      * <p>Calling this method leaves the view intact.</p>
      *
@@ -1077,9 +1078,10 @@ public class JXGraph extends JXPanel {
             return;
         }
 
+        Point2D old = getOrigin();
         originX = origin.getX();
         originY = origin.getY();
-
+        firePropertyChange("origin", old, getOrigin());
         repaint();
     }
 
