@@ -1,5 +1,5 @@
 /*
- * $Id: JXStatusBar.java,v 1.18 2008/10/14 22:32:49 rah003 Exp $
+ * $Id: JXStatusBar.java 3471 2009-08-27 13:10:39Z kleopatra $
  *
  * Copyright 2004 Sun Microsystems, Inc., 4150 Network Circle,
  * Santa Clara, California 95054, U.S.A. All rights reserved.
@@ -23,9 +23,11 @@ package org.jdesktop.swingx;
 
 
 import java.awt.Insets;
+
 import javax.swing.JComponent;
-import org.jdesktop.swingx.plaf.StatusBarAddon;
+
 import org.jdesktop.swingx.plaf.LookAndFeelAddons;
+import org.jdesktop.swingx.plaf.StatusBarAddon;
 import org.jdesktop.swingx.plaf.StatusBarUI;
 
 /**
@@ -59,7 +61,7 @@ import org.jdesktop.swingx.plaf.StatusBarUI;
  * is that left over after allowing for all FIXED component and the preferred 
  * width of FILL components, plus insets  
  * 
- * <p>Constructing a <code>JXStatusBar</code> is very straitforward:
+ * <p>Constructing a <code>JXStatusBar</code> is very straightforward:
  * <pre><code>
  *      JXStatusBar bar = new JXStatusBar();
  *      JLabel statusLabel = new JLabel("Ready");
@@ -96,6 +98,7 @@ import org.jdesktop.swingx.plaf.StatusBarUI;
  *
  * @author pdoubleya
  * @author rbair
+ * @author Karl George Schaefer
  */
 public class JXStatusBar extends JComponent {
     /**
@@ -104,6 +107,9 @@ public class JXStatusBar extends JComponent {
      */
     public static final String uiClassID = "StatusBarUI";
     
+    //TODO how to handle UI delegate setting of primitive?
+    private boolean resizeHandleEnabled;
+    
     /**
      * Initialization that would ideally be moved into various look and feel
      * classes.
@@ -117,10 +123,25 @@ public class JXStatusBar extends JComponent {
      */
     public JXStatusBar() {
         super();
-        setOpaque(true);
         updateUI();
     }
 
+    /**
+     * @param resizeHandleEnabled the resizeHandleEnabled to set
+     */
+    public void setResizeHandleEnabled(boolean resizeHandleEnabled) {
+        boolean oldValue = isResizeHandleEnabled();
+        this.resizeHandleEnabled = resizeHandleEnabled;
+        firePropertyChange("resizeHandleEnabled", oldValue, isResizeHandleEnabled());
+    }
+
+    /**
+     * @return the resizeHandleEnabled
+     */
+    public boolean isResizeHandleEnabled() {
+        return resizeHandleEnabled;
+    }
+
     /**
      * Returns the look and feel (L&F) object that renders this component.
      * 
@@ -136,9 +157,11 @@ public class JXStatusBar extends JComponent {
      * @param ui
      *            the StatusBarUI L&F object
      * @see javax.swing.UIDefaults#getUI
-     * @beaninfo bound: true hidden: true attribute: visualUpdate true
-     *           description: The UI object that implements the Component's
-     *           LookAndFeel.
+     * @beaninfo
+     *        bound: true
+     *       hidden: true
+     *    attribute: visualUpdate true
+     *  description: The component's look and feel delegate.
      */
     public void setUI(StatusBarUI ui) {
         super.setUI(ui);
