@@ -1,5 +1,5 @@
 /*
- * $Id: HighlightPredicate.java,v 1.26 2008/10/14 22:31:38 rah003 Exp $
+ * $Id: HighlightPredicate.java 3471 2009-08-27 13:10:39Z kleopatra $
  *
  * Copyright 2006 Sun Microsystems, Inc., 4150 Network Circle,
  * Santa Clara, California 95054, U.S.A. All rights reserved.
@@ -372,7 +372,7 @@ public interface HighlightPredicate {
             return false;
         }
         /**
-         * @return 
+         * @return all registered predicates
          */
         public HighlightPredicate[] getHighlightPredicates() {
             if (predicate.isEmpty()) return EMPTY_PREDICATE_ARRAY;
@@ -545,7 +545,7 @@ public interface HighlightPredicate {
         }
 
         /**
-         * @return
+         * @return array of numbers representing different depths
          */
         public Integer[] getDepths() {
             if (depthList.isEmpty()) return EMPTY_INTEGER_ARRAY;
@@ -625,7 +625,7 @@ public interface HighlightPredicate {
          * @param compareValue the fixed class to compare the 
          *   adapter value against.
          */
-        public TypeHighlightPredicate(Class compareValue) {
+        public TypeHighlightPredicate(Class<?> compareValue) {
             this.clazz = compareValue;
         }
         
@@ -640,7 +640,7 @@ public interface HighlightPredicate {
                     clazz.isAssignableFrom(adapter.getValue().getClass()) : false;
         }
         /**
-         * @return
+         * @return type of predicate compare class
          */
         public Class<?> getType() {
             return clazz;
