@@ -1,5 +1,5 @@
 /*
- * $Id: BasicHyperlinkUI.java,v 1.18 2008/12/05 14:34:56 kschaefe Exp $
+ * $Id: BasicHyperlinkUI.java 3344 2009-05-25 01:46:59Z kschaefe $
  *
  * Copyright 2004 Sun Microsystems, Inc., 4150 Network Circle,
  * Santa Clara, California 95054, U.S.A. All rights reserved.
@@ -43,12 +43,12 @@ import javax.swing.ButtonModel;
 import javax.swing.Icon;
 import javax.swing.JComponent;
 import javax.swing.JToolBar;
+import javax.swing.LookAndFeel;
 import javax.swing.SwingUtilities;
 import javax.swing.UIManager;
 import javax.swing.event.ChangeEvent;
 import javax.swing.plaf.BorderUIResource;
 import javax.swing.plaf.ComponentUI;
-import javax.swing.plaf.UIResource;
 import javax.swing.plaf.basic.BasicButtonListener;
 import javax.swing.plaf.basic.BasicButtonUI;
 import javax.swing.plaf.basic.BasicGraphicsUtils;
@@ -65,6 +65,8 @@ import javax.swing.text.html.HTMLEditorKit;
 import javax.swing.text.html.ImageView;
 import javax.swing.text.html.StyleSheet;
 
+import org.jdesktop.swingx.SwingXUtilities;
+
 /**
  * Basic implementation of the <code>JXHyperlink</code> UI. <br>
  * This is copied from org.jdesktop.jdnc.plaf.basic.BasicLinkButtonUI
@@ -112,10 +114,10 @@ public class BasicHyperlinkUI extends BasicButtonUI {
     protected void installDefaults(AbstractButton b) {
         super.installDefaults(b);
 
-        b.setOpaque(false);
+        LookAndFeel.installProperty(b, "opaque", false);
         b.setBorderPainted(false);
         b.setRolloverEnabled(true);
-        if (b.getBorder() == null || b.getBorder() instanceof UIResource) {
+        if (SwingXUtilities.isUIInstallable(b.getBorder())) {
             b.setBorder(new BorderUIResource(BorderFactory.createEmptyBorder(0, 1, 0, 0)));
         }
 
