@@ -1,5 +1,5 @@
 /*
- * $Id: TableColumnExt.java,v 1.30 2008/10/14 22:31:40 rah003 Exp $
+ * $Id: TableColumnExt.java 3472 2009-08-27 13:12:42Z kleopatra $
  *
  * Copyright 2004 Sun Microsystems, Inc., 4150 Network Circle,
  * Santa Clara, California 95054, U.S.A. All rights reserved.
@@ -102,7 +102,7 @@ import org.jdesktop.swingx.renderer.AbstractRenderer;
  * 
  * @see TableColumnModelExt
  * @see ColumnFactory
- * @see org.jdesktop.swingx.UIDependent
+ * @see org.jdesktop.swingx.decorator.UIDependent
  * @see javax.swing.JComponent#putClientProperty
  */
 public class TableColumnExt extends TableColumn implements UIDependent {
@@ -115,7 +115,7 @@ public class TableColumnExt extends TableColumn implements UIDependent {
 
 
     /** per-column comparator  */
-    protected Comparator comparator;
+    protected Comparator<?> comparator;
     /** per-column sortable property. Initialized to <code>true</code>. */
     protected boolean sortable = true;
     /** per-column editable property. Initialized to <code>true</code>.*/
@@ -266,7 +266,6 @@ public class TableColumnExt extends TableColumn implements UIDependent {
      * PENDING: open up for subclasses again?.
      * 
      * @return the CompoundHighlighter assigned to the table.
-     * @see #setCompoundHighlighter(CompoundHighlighter)
      */
     protected CompoundHighlighter getCompoundHighlighter() {
         if (compoundHighlighter == null) {
@@ -398,11 +397,11 @@ public class TableColumnExt extends TableColumn implements UIDependent {
      * @param comparator a custom comparator to use in interactive
      *    sorting.
      * @see #getComparator
-     * @see org.jdesktop.swingx.decorator.SortController
+     * @see org.jdesktop.swingx.sort.SortController
      * @see org.jdesktop.swingx.decorator.SortKey
      */
-    public void setComparator(Comparator comparator) {
-        Comparator old = getComparator();
+    public void setComparator(Comparator<?> comparator) {
+        Comparator<?> old = getComparator();
         this.comparator = comparator;
         firePropertyChange("comparator", old, getComparator());
     }
@@ -414,7 +413,7 @@ public class TableColumnExt extends TableColumn implements UIDependent {
      * @return <code>Comparator</code> to use for this column
      * @see #setComparator
      */
-    public Comparator getComparator() {
+    public Comparator<?> getComparator() {
         return comparator;
     }
 
@@ -615,7 +614,7 @@ public class TableColumnExt extends TableColumn implements UIDependent {
       * Copies all clientProperties of this <code>TableColumnExt</code>
       * to the target column.
       * 
-      * @param copy the target column.
+      * @param original the target column.
       */
      protected void copyClientPropertiesFrom(TableColumnExt original) {
         if (original.clientProperties == null) return;
