@@ -1,5 +1,5 @@
 /*
- * $Id: PaintUtils.java,v 1.17 2008/10/14 22:31:46 rah003 Exp $
+ * $Id: PaintUtils.java 3352 2009-05-25 16:37:52Z kschaefe $
  *
  * Copyright 2004 Sun Microsystems, Inc., 4150 Network Circle,
  * Santa Clara, California 95054, U.S.A. All rights reserved.
@@ -22,39 +22,21 @@
 package org.jdesktop.swingx.util;
 
 import java.awt.Color;
-import java.awt.Component;
-import java.awt.Container;
-import java.awt.Font;
 import java.awt.FontMetrics;
 import java.awt.GradientPaint;
 import java.awt.Graphics;
 import java.awt.Graphics2D;
-import java.awt.GraphicsConfiguration;
-import java.awt.GraphicsDevice;
-import java.awt.GraphicsEnvironment;
-import java.awt.Image;
 import java.awt.Paint;
 import java.awt.Rectangle;
-import java.awt.Shape;
-import java.awt.Transparency;
-import java.awt.geom.Area;
 import java.awt.geom.Point2D;
 import java.awt.geom.Rectangle2D;
-import java.awt.image.BufferedImage;
-import java.io.IOException;
-import java.io.InputStream;
 import java.lang.reflect.Constructor;
 import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
-import java.net.URL;
 
-import javax.imageio.ImageIO;
-import javax.swing.BorderFactory;
 import javax.swing.JComponent;
 import javax.swing.JLabel;
 import javax.swing.SwingConstants;
-import javax.swing.border.BevelBorder;
-import javax.swing.border.Border;
 
 /**
  * A collection of utilties for painting visual effects.
@@ -62,14 +44,6 @@ import javax.swing.border.Border;
  * @author Mark Davidson
  */
 public class PaintUtils {
-    private static GraphicsConfiguration configuration = GraphicsEnvironment.getLocalGraphicsEnvironment().getDefaultScreenDevice().getDefaultConfiguration();
-    
-    //  Utility methods.
-    private static Border defaultBorder =
-            BorderFactory.createBevelBorder(BevelBorder.RAISED);
-    
-    
-    
     public static final GradientPaint BLUE_EXPERIENCE = new GradientPaint(
             new Point2D.Double(0, 0),
             new Color(168, 204, 241),
@@ -115,10 +89,6 @@ public class PaintUtils {
     private PaintUtils() {
     }
     
-    public static Border getDefaultBorder() {
-        return defaultBorder;
-    }
-    
     /**
      * Returns the bounds that the text of a label will be drawn into.
      * Takes into account the current font metrics.
@@ -173,138 +143,6 @@ public class PaintUtils {
         g2.setPaint(oldPaint);
     }
     
-    /**
-     * Sets the background color for a containment hierarchy.
-     */
-    public static void setBackgroundColor(Container cont, Color color) {
-        cont.setBackground(color);
-        Component[] children = cont.getComponents();
-        for (Component aChildren : children) {
-            if (aChildren instanceof Container) {
-                setBackgroundColor((Container) aChildren, color);
-            } else {
-                aChildren.setBackground(color);
-            }
-        }
-    }
-    
-    /**
-     * Sets the foreground color for a containment hierarchy.
-     */
-    public static void setForegroundColor(Container cont, Color color) {
-        cont.setForeground(color);
-        Component[] children = cont.getComponents();
-        for (Component aChildren : children) {
-            if (aChildren instanceof Container) {
-                setForegroundColor((Container) aChildren, color);
-            } else {
-                aChildren.setForeground(color);
-            }
-        }
-    }
-    
-    /**
-     * Sets the font for a containment hierarchy.
-     */
-    public static void setFont(Container cont, Font font) {
-        cont.setFont(font);
-        Component[] children = cont.getComponents();
-        for (Component aChildren : children) {
-            if (aChildren instanceof Container) {
-                setFont((Container) aChildren, font);
-            } else {
-                aChildren.setFont(font);
-            }
-        }
-    }
-    
-    /**
-     * @param width  the width of the new BufferedImage
-     * @param height the height of the new BufferedImage
-     *
-     * @return Creates and returns a BufferedImage that is "compatible" with this machines
-     *         video card and subsystem
-     */
-    public static BufferedImage createCompatibleImage(int width, int height) {
-        GraphicsEnvironment environment =
-                GraphicsEnvironment.getLocalGraphicsEnvironment();
-        GraphicsDevice screenDevice = environment.getDefaultScreenDevice();
-        GraphicsConfiguration configuration =
-                screenDevice.getDefaultConfiguration();
-        return configuration.createCompatibleImage(width, height);
-    }
-    
-    /**
-     * @param width         the width of the new BufferedImage
-     * @param height        the height of the new BufferedImage
-     * @param transparency  one of the values in the Transparency interface
-     *
-     * @return Creates and returns a BufferedImage that is "compatible" with this machines
-     *         video card and subsystem with the given Transparency.
-     */
-    public static BufferedImage createCompatibleImage(int width, int height,
-            int transparency) {
-        GraphicsEnvironment environment =
-                GraphicsEnvironment.getLocalGraphicsEnvironment();
-        GraphicsDevice screenDevice = environment.getDefaultScreenDevice();
-        GraphicsConfiguration configuration =
-                screenDevice.getDefaultConfiguration();
-        return configuration.createCompatibleImage(width, height, transparency);
-    }
-    
-    public static BufferedImage convertToBufferedImage(Image img) {
-        BufferedImage buff = createCompatibleImage(img.getWidth(null),img.getHeight(null));
-        Graphics2D g2 = buff.createGraphics();
-        g2.drawImage(img,0,0,null);
-        g2.dispose();
-        return buff;
-    }
-    
-    /**
-     * Loads the image at the URL and makes it compatible with the screen.
-     * If loading the url fails then this method will either throw an IOException
-     * or return null.
-     */
-    public static BufferedImage loadCompatibleImage(URL resource) throws IOException {
-        BufferedImage image = ImageIO.read(resource);
-        if(image == null) return null;
-        return toCompatibleImage(image);
-    }
-    
-    public static BufferedImage loadCompatibleImage(InputStream in) throws IOException {
-        BufferedImage image = ImageIO.read(in);
-        if(image == null) return null;
-        return toCompatibleImage(image);
-    }
-    
-    public static BufferedImage toCompatibleImage(BufferedImage image) {
-        BufferedImage compatibleImage = configuration.createCompatibleImage(image.getWidth(),
-                image.getHeight(), Transparency.TRANSLUCENT);
-        Graphics g = compatibleImage.getGraphics();
-        g.drawImage(image, 0, 0, null);
-        g.dispose();
-        return compatibleImage;
-    }
-    
-    
-    /** Sets then clip on a graphics object by merging with the existing
-     * clip instead of replacing it. The new clip will be an intersection of
-     * the old clip and the passed in clip shape.   The old clip shape will
-     * be returned
-     */
-    public static Shape setMergedClip(Graphics2D g, Shape newClip) {
-        Shape oldClip = g.getClip();
-        if(oldClip == null) {
-            g.setClip(newClip);
-            return null;
-        }
-        Area area = new Area(oldClip);
-        area.intersect(new Area(newClip));//new Rectangle(0,0,width,height)));
-        g.setClip(area);
-        return oldClip;
-    }
-    
-    
     /** Resizes a gradient to fill the width and height available. If the
      * gradient is left to right it will be resized to fill the entire width.
      * If the gradient is top to bottom it will be resized to fill the entire
