@@ -1,5 +1,5 @@
 /*
- * $Id: JXDatePickerIssues.java,v 1.71 2008/12/01 14:14:42 kleopatra Exp $
+ * $Id: JXDatePickerIssues.java 3473 2009-08-27 13:17:10Z kleopatra $
  *
  * Copyright 2006 Sun Microsystems, Inc., 4150 Network Circle,
  * Santa Clara, California 95054, U.S.A. All rights reserved.
@@ -26,6 +26,13 @@ import java.awt.Dimension;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.awt.event.KeyEvent;
+import java.beans.PropertyChangeEvent;
+import java.beans.PropertyChangeListener;
+import java.text.DateFormatSymbols;
+import java.text.DecimalFormat;
+import java.text.DecimalFormatSymbols;
+import java.text.NumberFormat;
+import java.text.SimpleDateFormat;
 import java.util.Calendar;
 import java.util.Date;
 import java.util.Locale;
@@ -63,13 +70,13 @@ public class JXDatePickerIssues extends InteractiveTestCase {
     private static final Logger LOG = Logger.getLogger(JXDatePickerIssues.class
             .getName());
     public static void main(String[] args) {
-//        setSystemLF(true);
+        setSystemLF(true);
 //        Trace14.keyboardFocusManager(true);
         JXDatePickerIssues  test = new JXDatePickerIssues();
         try {
 //            test.runInteractiveTests();
 //          test.runInteractiveTests("interactive.*UpdateUI.*");
-          test.runInteractiveTests("interactive.*Editor.*");
+          test.runInteractiveTests("interactive.*Symbols.*");
 //          test.runInteractiveTests("interactive.*Visible.*");
           
         } catch (Exception e) {
@@ -78,9 +85,60 @@ public class JXDatePickerIssues extends InteractiveTestCase {
         }
     }
 
+    public void interactiveDateSymbols() {
+        for (Locale locale : Locale.getAvailableLocales()) {
+            LOG.info("locale " + locale + locale.getDisplayCountry());
+        }
+        DecimalFormat df = (DecimalFormat) NumberFormat.getInstance(new Locale("ar", "KW"));
+        DecimalFormatSymbols dfs = new DecimalFormatSymbols(new Locale("ar", "KW"));//df.getDecimalFormatSymbols();
+        LOG.info("" + df + " zero " + dfs.getZeroDigit());
+        LOG.info("" + dfs);
+        df.setDecimalFormatSymbols(dfs);
+        @SuppressWarnings("unused")
+        DateFormatSymbols dateSymbols = null;
+        // set the beginning of the range to Arabic digits
+//        dfs.setZeroDigit('\u0660');
+//        df.setDecimalFormatSymbols(dfs);
+        JXDatePicker picker = new JXDatePicker(new Locale("ar", "KW"));
+        JLabel label1 = new JLabel(df.format(1));
+        JLabel label2 = new JLabel(df.format(2));
+        JComponent component = new JPanel();
+        component.add(label1);
+        component.add(label2);
+        component.add(picker);
+        showInFrame(component, "Symbos");
+        System.out.println(df.format(1));
+        System.out.println(df.format(2));
+    }
 
-    private Calendar calendar;
+    /**
+     * Issue #??-swingx: first week of year in year-week format invalid?
+     * 
+     * Same problem for formattedTextField.
+     */
+    public void interactiveYearWeekFormat() {
+        JComponent box = Box.createVerticalBox();
+        calendar.set(2009, Calendar.JANUARY, 1);
+        JXDatePicker picker = new JXDatePicker(calendar.getTime());
+        SimpleDateFormat format = new SimpleDateFormat("yyww");
+        format.setLenient(false);
+        picker.setFormats(format);
+        picker.getMonthView().setShowingWeekNumber(true);
+        box.add(picker);
+        JFormattedTextField field = new JFormattedTextField(format);
+        field.setValue(picker.getDate());
+        box.add(field);
+        PropertyChangeListener l = new PropertyChangeListener() {
 
+            public void propertyChange(PropertyChangeEvent evt) {
+                LOG.info(evt.getPropertyName() + evt.getSource().getClass().getSimpleName() + evt.getNewValue());
+                
+            }};
+        field.addPropertyChangeListener(l);
+        picker.addPropertyChangeListener(l);
+        showInFrame(box, "yearweek format");
+    }
+    
     /**
      * Issue #955-swingx: editor should have same visual props as picker
      */
@@ -207,7 +265,7 @@ public class JXDatePickerIssues extends InteractiveTestCase {
         comp.add(new JLabel("setDate(null)"));
         JXDatePicker picker = new JXDatePicker();
         comp.add(picker);
-        comp.add(new JLabel("initial -1"));
+        comp.add(new JTextField("initial -1"));
         showInFrame(comp, "null date");
     }
 
@@ -571,6 +629,8 @@ public class JXDatePickerIssues extends InteractiveTestCase {
 
 
 
+
+    private Calendar calendar;
     
 
     @Override
