@@ -1,5 +1,5 @@
 /*
- * $Id: JXDatePickerTest.java,v 1.71 2008/12/01 14:14:42 kleopatra Exp $
+ * $Id: JXDatePickerTest.java 3497 2009-09-09 13:42:32Z kleopatra $
  * 
  * Copyright 2006 Sun Microsystems, Inc., 4150 Network Circle,
  * Santa Clara, California 95054, U.S.A. All rights reserved.
@@ -25,11 +25,13 @@ import java.awt.Container;
 import java.awt.Dimension;
 import java.awt.GraphicsEnvironment;
 import java.awt.event.ActionListener;
+import java.lang.reflect.InvocationTargetException;
 import java.text.DateFormat;
 import java.text.Format;
 import java.text.MessageFormat;
 import java.text.ParseException;
 import java.text.SimpleDateFormat;
+import java.util.Arrays;
 import java.util.Calendar;
 import java.util.Date;
 import java.util.Locale;
@@ -44,8 +46,11 @@ import javax.swing.JFormattedTextField;
 import javax.swing.JPanel;
 import javax.swing.JTextField;
 import javax.swing.KeyStroke;
+import javax.swing.SwingUtilities;
 import javax.swing.UIManager;
 import javax.swing.border.Border;
+import javax.swing.plaf.UIResource;
+import javax.swing.text.DateFormatter;
 import javax.swing.text.DefaultFormatterFactory;
 
 import org.jdesktop.swingx.calendar.CalendarUtils;
@@ -57,6 +62,7 @@ import org.jdesktop.swingx.plaf.UIManagerExt;
 import org.jdesktop.swingx.plaf.basic.BasicDatePickerUI.EditorCancelAction;
 import org.jdesktop.swingx.test.XTestUtils;
 import org.jdesktop.test.ActionReport;
+import org.jdesktop.test.PopupMenuReport;
 import org.jdesktop.test.PropertyChangeReport;
 import org.jdesktop.test.TestUtils;
 import org.junit.After;
@@ -87,6 +93,81 @@ public class JXDatePickerTest extends InteractiveTestCase {
        public void tearDown() {
     }
 
+    /**
+     * Issue #1171-swingx: support popupMenuListeners.
+     * 
+     * Tests notification on showing.
+     * @throws InvocationTargetException 
+     * @throws InterruptedException 
+     */
+    @Test
+    public void testPopupMenuListenerNotificationVisible() throws InterruptedException, InvocationTargetException {
+        if (GraphicsEnvironment.isHeadless()) {
+            LOG.fine("cannot run testLinkPanelNull - headless");
+            return;
+        }
+        final JXDatePicker picker = new JXDatePicker();
+        final JXFrame frame = new JXFrame("showing", false);
+        frame.add(picker);
+        frame.pack();
+        frame.setVisible(true);
+        final PopupMenuReport report = new PopupMenuReport();
+        picker.addPopupMenuListener(report);
+        Action togglePopup = picker.getActionMap().get("TOGGLE_POPUP");
+        togglePopup.actionPerformed(null);
+        SwingUtilities.invokeAndWait(new Runnable() {
+            public void run() {
+                assertEquals(1, report.getEventCount());
+                assertEquals(1, report.getVisibleEventCount());
+                frame.dispose();
+                
+            }
+        });
+    }
+    
+    
+    /**
+     * Issue #1171-swingx: support popupMenuListeners.
+     * 
+     * Tests add/remove.
+     */
+    @Test
+    public void testPopupMenuListenerManagement() {
+        JXDatePicker picker = new JXDatePicker();
+        assertNotNull(picker.getPopupMenuListeners());
+        int count = picker.getPopupMenuListeners().length;
+        PopupMenuReport report = new PopupMenuReport();
+        picker.addPopupMenuListener(report);
+        assertEquals(count + 1, picker.getPopupMenuListeners().length);
+        assertTrue(Arrays.asList(picker.getPopupMenuListeners()).contains(report));
+        picker.removePopupMenuListener(report);
+        assertEquals(count, picker.getPopupMenuListeners().length);
+        assertFalse(Arrays.asList(picker.getPopupMenuListeners()).contains(report));
+    }
+    /**
+     * Issue #1144-swingx: JXDatePicker must accept custom formatter.
+     * Pathological .. but anyway: formatter may be null.
+     * Issue manifests in throwing NPE.
+     */
+    @Test
+    public void testCustomFormatterNull() {
+        JXDatePicker picker = new JXDatePicker();
+        DefaultFormatterFactory factory = new DefaultFormatterFactory();
+        assertEquals("sanity (null formatter): ", null, factory.getFormatter(picker.getEditor()));
+        picker.getEditor().setFormatterFactory(factory);
+        picker.updateUI();
+    }
+    /**
+     * Issue #1144-swingx: JXDatePicker must accept custom formatter.
+     * Use core DateFormatter - issue manifests in throwing classcastEx
+     */
+    @Test
+    public void testCustomFormatterCore() {
+        JXDatePicker picker = new JXDatePicker();
+        DefaultFormatterFactory factory = new DefaultFormatterFactory(new DateFormatter());
+        picker.getEditor().setFormatterFactory(factory);
+        picker.updateUI();
+    }
     
     /**
      * Issue #910-swingx: home commit must be disabled if picker not editable.
@@ -294,7 +375,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
     @Test
     public void testVisibleMonthContainsSelectionOpenSet() {
         if (GraphicsEnvironment.isHeadless()) {
-            LOG.info("cannot run testLinkPanelNull - headless");
+            LOG.fine("cannot run testLinkPanelNull - headless");
             return;
         }
         calendar.set(2008, Calendar.JULY, 15);
@@ -322,7 +403,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
     @Test
     public void testVisibleMonthContainsSelectionOpenInitial() {
         if (GraphicsEnvironment.isHeadless()) {
-            LOG.info("cannot run testLinkPanelNull - headless");
+            LOG.fine("cannot run testLinkPanelNull - headless");
             return;
         }
         calendar.set(2008, Calendar.JULY, 15);
@@ -600,7 +681,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
     @Test
     public void testLinkPanelSetNull() {
         if (GraphicsEnvironment.isHeadless()) {
-            LOG.info("cannot run testLinkPanelNull - headless");
+            LOG.fine("cannot run testLinkPanelNull - headless");
             return;
         }
         JXDatePicker picker = new JXDatePicker();
@@ -620,7 +701,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
     @Test
     public void testLinkPanelInitalNull() {
         if (GraphicsEnvironment.isHeadless()) {
-            LOG.info("cannot run testLinkPanelNull - headless");
+            LOG.fine("cannot run testLinkPanelNull - headless");
             return;
         }
         JXDatePicker picker = new JXDatePicker();
@@ -641,7 +722,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
     @Test
     public void testLinkPanelRemovedAdded() {
         if (GraphicsEnvironment.isHeadless()) {
-            LOG.info("cannot run testLinkPanelNull - headless");
+            LOG.fine("cannot run testLinkPanelNull - headless");
             return;
         }
         JXDatePicker picker = new JXDatePicker();
@@ -762,13 +843,14 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * test that the toggle popup is registered in the 
      * picker's actionMap.
      *
+     * Issue #596-swingx: don't use space to open popup.
      */
     @Test
     public void testTogglePopupAction() {
        JXDatePicker picker = new JXDatePicker();
        Action togglePopup = picker.getActionMap().get("TOGGLE_POPUP");
        assertNotNull(togglePopup);
-       KeyStroke space = KeyStroke.getKeyStroke("SPACE");
+       KeyStroke space = KeyStroke.getKeyStroke("alt DOWN");
        Object actionKey = picker.getInputMap(
                JComponent.WHEN_ANCESTOR_OF_FOCUSED_COMPONENT)
                .get(space);
@@ -1576,7 +1658,17 @@ public class JXDatePickerTest extends InteractiveTestCase {
         assertEquals(date, picker.getEditor().getValue());
     }
 
-
+    @Test
+    public void testEditorUIResource() {
+        JXDatePicker picker = new JXDatePicker();
+        // this is safe: ui must install an editor and it must be of type UIResource
+        assertEquals("default editor is UIResource ", true, picker.getEditor() instanceof UIResource);
+        JFormattedTextField editor = new JFormattedTextField();
+        picker.setEditor(editor);
+        assertEquals("sanity: custom editor not UIResource ", false, picker.getEditor() instanceof UIResource);
+        picker.updateUI();
+        assertSame("updateUI must not touch custom editor", editor, picker.getEditor()); 
+    }
 
     /**
      * Characterization: setting the monthview's selection model updates
