@@ -39,6 +39,7 @@ import java.util.logging.Logger;
 import javax.swing.AbstractAction;
 import javax.swing.Action;
 import javax.swing.Box;
+import javax.swing.JCheckBox;
 import javax.swing.JComboBox;
 import javax.swing.JComponent;
 import javax.swing.JFormattedTextField;
@@ -56,6 +57,8 @@ import javax.swing.UIManager;
 import javax.swing.UnsupportedLookAndFeelException;
 import javax.swing.JSpinner.DefaultEditor;
 import javax.swing.UIManager.LookAndFeelInfo;
+import javax.swing.event.PopupMenuEvent;
+import javax.swing.event.PopupMenuListener;
 import javax.swing.text.DateFormatter;
 import javax.swing.text.DefaultFormatterFactory;
 
@@ -93,9 +96,9 @@ public class JXDatePickerVisualCheck extends InteractiveTestCase {
         JXDatePickerVisualCheck test = new JXDatePickerVisualCheck();
         
         try {
-            test.runInteractiveTests();
+//            test.runInteractiveTests();
 //            test.runInteractiveTests("interactive.*PrefSize.*");
-//            test.runInteractiveTests("interactive.*Keep.*");
+            test.runInteractiveTests("interactive.*MenuListener.*");
 //          test.runInteractiveTests("interactive.*Multiple.*");
 //            test.runInteractiveTests("interactive.*Event.*");
         } catch (Exception e) {
@@ -104,6 +107,28 @@ public class JXDatePickerVisualCheck extends InteractiveTestCase {
         }
     }
 
+    public void interactivePopupMenuListener() {
+        JXDatePicker picker = new JXDatePicker();
+        PopupMenuListener l = new PopupMenuListener() {
+            
+            @Override
+            public void popupMenuWillBecomeVisible(PopupMenuEvent e) {
+                LOG.info("visible");
+            }
+            
+            @Override
+            public void popupMenuWillBecomeInvisible(PopupMenuEvent e) {
+                LOG.info("invisible");
+            }
+            
+            @Override
+            public void popupMenuCanceled(PopupMenuEvent e) {
+                LOG.info("canceled");
+            }
+        };
+        picker.addPopupMenuListener(l);
+        showInFrame(picker, "notification?");
+    }
     /**
      * Issue #940-swingx: support multiple selection in picker.
      * Nothing out-off-the-box, trying to implement custom 
@@ -238,13 +263,16 @@ public class JXDatePickerVisualCheck extends InteractiveTestCase {
      * clicking into other focus-tricksing component (like
      * picker, combo).
      * 
+     * Issue #1011-swingx: popup of first picker opened on click on second
+     * (mac only?)
+     * 
      * And: Compare picker and combo behaviour on toggle lf.
      * 
      * Not really comparable: the combo has complete control over the popup, re-creates
      * both popup and content on install.
      * 
      */
-    public void interactiveUpdateUIPickerCompareCombo() {
+    public void interactivePopupPickerCompareCombo() {
 //      Trace14.keyboardFocusManager(true);
        final JXDatePicker picker = new JXDatePicker();
        picker.getEditor().setName("first DateField");
@@ -254,11 +282,30 @@ public class JXDatePickerVisualCheck extends InteractiveTestCase {
         comp.add(picker);
         comp.add(new JXDatePicker(new Date()));
         comp.add(box);
-        JXFrame frame = wrapInFrame(comp, "compare combo <-> picker", true);
+        JXFrame frame = wrapInFrame(comp, "compare combo <-> picker, picker <-> picker", true);
         addMessage(frame, "open popup, click in other picker/combo - popup must close and other focused");
         show(frame);
     }
     
+    /**
+     * Issue #1011-swingx: popup of first picker opened on click on second
+     * (mac only?)
+     * 
+     */
+    public void interactivePopupTwoPickers() {
+//      Trace14.keyboardFocusManager(true);
+       final JXDatePicker picker = new JXDatePicker();
+       picker.getEditor().setName("first DateField");
+        JComponent comp = new JPanel();
+        comp.add(picker);
+        JXDatePicker other = new JXDatePicker(new Date());
+        comp.add(other);
+//        other.setFocusable(false);
+//        picker.setFocusable(false);
+        JXFrame frame = wrapInFrame(comp, "popup: picker <-> picker", true);
+        addMessage(frame, "click on second opens popup of first (mac only?)");
+        show(frame, 400, 400);
+    }
 
     
     /**
@@ -324,7 +371,12 @@ public class JXDatePickerVisualCheck extends InteractiveTestCase {
      * Behaviour defined by selection model of monthView. While the default 
      * (DaySelectionModel) normalizes the dates to the start of the day in the
      * model's calendar coordinates, a SingleDaySelectionModel keeps the date as-is.
-     * For now, need to explicitly set. 
+     * For now, need to explicitly set. <p>
+     * 
+     * Note: picking a date in the monthView still resets. And may lead to 
+     * inconsistent fields (picker.date different from editor/model selected) the
+     * latter being normalized? Not reproducible here - in the reported example 
+     * the time-part was hard-set when getting an actionEvent from the monthView.
      */
     public void interactiveKeepTimeFields() {
         final JXDatePicker picker = new JXDatePicker();
@@ -340,6 +392,9 @@ public class JXDatePickerVisualCheck extends InteractiveTestCase {
             public void propertyChange(PropertyChangeEvent evt) {
                 if ("date".equals(evt.getPropertyName())) {
                     field.setValue(evt.getNewValue());
+                    LOG.info("picker/editor/monthView: " + picker.getDate() + "/" 
+                           + picker.getEditor().getValue() + "/"
+                           + picker.getMonthView().getSelectionDate());
                 }
                 
             }
@@ -364,6 +419,66 @@ public class JXDatePickerVisualCheck extends InteractiveTestCase {
         
     }
 
+    /**
+     * Issue #568-swingx: DatePicker must not reset time fields.
+     * 
+     * Behaviour defined by selection model of monthView. While the default 
+     * (DaySelectionModel) normalizes the dates to the start of the day in the
+     * model's calendar coordinates, a SingleDaySelectionModel keeps the date as-is.
+     * For now, need to explicitly set. <p>
+     * 
+     * Note: picking a date in the monthView still resets. And may lead to 
+     * inconsistent fields (picker.date different from editor/model selected) the
+     * latter being normalized? Not reproducible here - in the reported example 
+     * the time-part was hard-set when getting an actionEvent from the monthView.
+     */
+    public void interactiveKeepEndOfDay() {
+        final JXDatePicker picker = new JXDatePicker();
+        SingleDaySelectionModel selectionModel = new SingleDaySelectionModel() {
+
+            @Override
+            public Date getNormalizedDate(Date date) {
+                return endOfDay(date);
+            }
+            
+        };
+        picker.getMonthView().setSelectionModel(selectionModel);
+        picker.setDate(new Date());
+        DateFormat format = DateFormat.getDateTimeInstance(DateFormat.MEDIUM, DateFormat.FULL);
+        picker.setFormats(format);
+        final JFormattedTextField field = new JFormattedTextField(format);
+        field.setValue(picker.getDate());
+        PropertyChangeListener l = new PropertyChangeListener() {
+
+            public void propertyChange(PropertyChangeEvent evt) {
+                if ("date".equals(evt.getPropertyName())) {
+                    field.setValue(evt.getNewValue());
+                    LOG.info("picker/editor/monthView: " + picker.getDate() + "/" 
+                           + picker.getEditor().getValue() + "/"
+                           + picker.getMonthView().getSelectionDate());
+                }
+                
+            }
+            
+        };
+        picker.addPropertyChangeListener(l);
+        Action setDate = new AbstractActionExt("set date") {
+
+            public void actionPerformed(ActionEvent e) {
+                picker.setDate(new Date());
+                
+            }
+            
+        };
+        JComponent box = Box.createHorizontalBox();
+        box.add(picker);
+        box.add(field);
+        JXFrame frame = wrapInFrame(box, "end of day");
+        addAction(frame, setDate);
+        frame.pack();
+        frame.setVisible(true);
+        
+    }
     /**
      * Issue #706-swingx: picker doesn't update monthView.
      * 
@@ -687,6 +802,7 @@ public class JXDatePickerVisualCheck extends InteractiveTestCase {
         
     }
     
+
     /**
      * Issue #235-swingx: action events
      * 
@@ -713,15 +829,15 @@ public class JXDatePickerVisualCheck extends InteractiveTestCase {
      * 
      * 
      */
-    public void interactiveActionEvent() {
+    public void interactiveActionEventSetAction() {
         JXDatePicker picker = new JXDatePicker();
         JTextField simpleField = new JTextField("simple field");
         JFormattedTextField textField = new JFormattedTextField(DateFormat.getDateInstance());
         textField.setValue(new Date());
         JComboBox box = new JComboBox(new Object[] {"one", "two", "three"});
         box.setEditable(true);
-        
-        ActionListener l = new ActionListener() {
+        JComboBox nonEditableBox = new JComboBox(new Object[] {"one", "two", "three"});
+        final Action l = new AbstractActionExt("recived") {
 
             public void actionPerformed(ActionEvent e) {
                 LOG.info("got action from: " + e.getSource().getClass().getName() + 
@@ -729,19 +845,31 @@ public class JXDatePickerVisualCheck extends InteractiveTestCase {
             }
             
         };
-        simpleField.addActionListener(l);
-        textField.addActionListener(l);
+        simpleField.setAction(l);
+        textField.setAction(l);
+        // picker doesn't have action-related api
         picker.addActionListener(l);
 //        picker.getMonthView().addActionListener(l);
-        box.addActionListener(l);
+        box.setAction(l);
+        nonEditableBox.setAction(l);
+        
         JPanel panel = new JPanel();
         panel.add(simpleField);
         panel.add(textField);
         panel.add(picker);
         panel.add(box);
-        
-        JXFrame frame = showInFrame(panel, "Compare action events: keyboard/mouse");
-        frame.pack();
+        panel.add(new JCheckBox(l));
+        panel.add(nonEditableBox);
+        JXFrame frame = wrapInFrame(panel, "SetAction - Compare action events: keyboard/mouse");
+        Action toggleEnabled = new AbstractActionExt("toggleEnabledAction") {
+
+            public void actionPerformed(ActionEvent e) {
+                l.setEnabled(!l.isEnabled());
+            }
+            
+        };
+        addAction(frame, toggleEnabled);
+        show(frame);
     }
 
     /**
