@@ -115,7 +115,7 @@ public class JXLoginPaneVisualCheck extends InteractiveTestCase {
      */
     public void interactiveSetBackground() {
         JXLoginPane panel = new JXLoginPane();
-        panel.setBackgroundPainter(new MattePainter<Object>(Color.RED, true));
+        panel.setBackgroundPainter(new MattePainter(Color.RED, true));
         JFrame frame = JXLoginPane.showLoginFrame(panel);
         frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
         frame.setJMenuBar(createAndFillMenuBar(panel));
@@ -150,12 +150,10 @@ public class JXLoginPaneVisualCheck extends InteractiveTestCase {
         JComponent.setDefaultLocale(Locale.FRANCE);
         final JXLoginPane panel = new JXLoginPane(new LoginService() {
 
+                        @Override
                         public boolean authenticate(String name, char[] password,
                                         String server) throws Exception {
-                                if (true) {
                                         throw new Exception("Ex.");
-                                }
-                                return false;
                         }});
         final JXLoginFrame frame = JXLoginPane.showLoginFrame(panel);
         // if uncommented dialog will disappear immediately due to invocation of login action
@@ -182,12 +180,10 @@ public class JXLoginPaneVisualCheck extends InteractiveTestCase {
         JComponent.setDefaultLocale(Locale.FRANCE);
         final JXLoginPane panel = new JXLoginPane(new LoginService() {
 
+                        @Override
                         public boolean authenticate(String name, char[] password,
                                         String server) throws Exception {
-                                if (true) {
                                         throw new Exception("Ex.");
-                                }
-                                return false;
                         }});
         final JXLoginFrame frame = JXLoginPane.showLoginFrame(panel);
         // if uncomented dialog will disappear immediatelly dou to invocation of login action
@@ -196,7 +192,7 @@ public class JXLoginPaneVisualCheck extends InteractiveTestCase {
         panel.setErrorMessage("TO TO TO TO TO TO TO TO TO TO TO TO TO TO TO TO TO TO TO TO TO TO Unexpected resize on long exception message. Unexpected resize on long exception message.");
 
         panel.setSaveMode(SaveMode.BOTH);
-        frame.getContentPane().setBackgroundPainter(new MattePainter<Object>(
+        frame.getContentPane().setBackgroundPainter(new MattePainter(
                 new GradientPaint(0, 0, Color.BLUE, 1, 0, Color.YELLOW), true));
 
         frame.pack();
@@ -216,7 +212,8 @@ public class JXLoginPaneVisualCheck extends InteractiveTestCase {
         final JFrame frame = JXLoginPane.showLoginFrame(panel);
         panel.setLoginService(new LoginService() {
 
-			public boolean authenticate(String name, char[] password,
+			@Override
+            public boolean authenticate(String name, char[] password,
 					String server) throws Exception {
 				panel.startLogin();
 				Thread.sleep(5000);
@@ -265,9 +262,14 @@ public class JXLoginPaneVisualCheck extends InteractiveTestCase {
             Image banner = super.getBanner();
             BufferedImage im = GraphicsUtilities.createCompatibleTranslucentImage(banner.getWidth(null), banner.getHeight(null));
             Graphics2D g = im.createGraphics();
-            g.setComposite(AlphaComposite.Src);
-            g.drawImage(banner, 0, 0, 100, 100, null);
-            g.dispose();
+            
+            try {
+                g.setComposite(AlphaComposite.Src);
+                g.drawImage(banner, 0, 0, 100, 100, null);
+            } finally {
+                g.dispose();
+            }
+            
             return im;
         }
     }
@@ -296,7 +298,9 @@ public class JXLoginPaneVisualCheck extends InteractiveTestCase {
      * @throws Exception
      */
     public void interactiveBrokenLayoutAfterFailedLogin() throws Exception {
-        sun.awt.AppContext.getAppContext().put("JComponent.defaultLocale", Locale.FRANCE);
+        // PENDING JW: removed while fixing #1186-swingx (no dependency on sun packages)
+        // revisit: why do we do this at all? If really needed replace
+//        sun.awt.AppContext.getAppContext().put("JComponent.defaultLocale", Locale.FRANCE);
         Map<String, char[]> aMap = new HashMap<String, char[]>();
         aMap.put("asdf", "asdf".toCharArray());
         JXLoginPane panel = new JXLoginPane(new SimpleLoginService(aMap));
