@@ -1,5 +1,5 @@
 /*
- * $Id: JXMonthViewVisualCheck.java,v 1.38 2008/10/30 16:38:39 kleopatra Exp $
+ * $Id: JXMonthViewVisualCheck.java 3497 2009-09-09 13:42:32Z kleopatra $
  *
  * Copyright 2006 Sun Microsystems, Inc., 4150 Network Circle,
  * Santa Clara, California 95054, U.S.A. All rights reserved.
@@ -22,6 +22,8 @@
 package org.jdesktop.swingx;
 
 import java.awt.Color;
+import java.awt.ComponentOrientation;
+import java.awt.Font;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.awt.event.MouseAdapter;
@@ -42,8 +44,11 @@ import javax.swing.JComponent;
 import javax.swing.JPanel;
 import javax.swing.UIManager;
 
+import org.jdesktop.swingx.JXMonthViewTest.Clock;
 import org.jdesktop.swingx.action.AbstractActionExt;
 import org.jdesktop.swingx.calendar.CalendarUtils;
+import org.jdesktop.swingx.calendar.DateSelectionModel;
+import org.jdesktop.swingx.calendar.SingleDaySelectionModel;
 import org.jdesktop.swingx.calendar.DateSelectionModel.SelectionMode;
 import org.jdesktop.swingx.event.DateSelectionEvent;
 import org.jdesktop.swingx.event.DateSelectionListener;
@@ -66,17 +71,90 @@ public class JXMonthViewVisualCheck extends InteractiveTestCase {
       setSystemLF(true);
       JXMonthViewVisualCheck  test = new JXMonthViewVisualCheck();
       try {
-          test.runInteractiveTests();
-//        test.runInteractiveTests(".*TimeZone.*");
-//        test.runInteractiveTests("interactive.*Zoomable.*");
+//          test.runInteractiveTests();
+//        test.runInteractiveTests(".*Event.*");
+//          test.runInteractiveTests("interactive.*Zoomable.*");
+//          test.runInteractiveTests("interactive.*Title.*");
+        test.runInteractiveTests("interactive.*LastDisplayed.*");
       } catch (Exception e) {
           System.err.println("exception when executing interactive tests:");
           e.printStackTrace();
       }
   }
+    
+    /**
+     * LastDisplayed incorrect?
+     */
+    public void interactiveLastDisplayedMultiple() {
+        final JXMonthView monthView = new JXMonthView();
+        monthView.setPreferredColumnCount(2);
+        JXFrame frame = wrapInFrame(monthView, "lastDisplayed");
+        Action action = new AbstractAction("print last") {
+            
+            @Override
+            public void actionPerformed(ActionEvent e) {
+                LOG.info("last displayed " + monthView.getLastDisplayedDay());
+            }
+        };
+        addAction(frame, action);
+        show(frame);
+    }
 
+    /**
+     * Issue #1125-swingx: JXMonthView today incorrect.
+     * Visual partly fix: updated in addNotify.
+     */
+    public void interactiveTodayUpdateInPicker() {
+        final Clock clock = new Clock();
+        JXMonthView monthView = JXMonthViewTest.createMonthViewWithClock(clock);
+        JXDatePicker picker = new JXDatePicker();
+        picker.setMonthView(monthView);
+        JXFrame frame = wrapInFrame(picker, "today ");
+        Action nextDay = new AbstractAction("next today - update via addNotify") {
+            
+            @Override
+            public void actionPerformed(ActionEvent e) {
+                clock.nextDay();
+                
+            }
+        };
+        addAction(frame, nextDay);
+        show(frame);
+    }
+
+    /**
+     * Issue #1028-swingx: monthView title looks wrong if box paddings = 0
+     */
+    public void interactiveTitleBorder() {
+        JXMonthView monthView = new JXMonthView();
+        monthView.setBoxPaddingX(0);
+        monthView.setBoxPaddingY(0);
+        monthView.setTraversable(true);
+        JComponent comp = Box.createHorizontalBox();
+        comp.add(monthView);
+        JXMonthView other = new JXMonthView();
+        other.setTraversable(true);
+        comp.add(other);
+        showInFrame(comp, "monthView title border");
+        
+    }
+
+    /**
+     * Issue 807-swingx: JXMonthView must have visual clue if enabled.
+     */
+    public void interactiveDisabled() {
+        JXMonthView monthView = new JXMonthView();
+        monthView.setEnabled(false);
+        JComponent comp = Box.createHorizontalBox();
+        comp.add(monthView);
+        comp.add(new JXMonthView());
+        showInFrame(comp, "disabled <--> enabled");
+    }
+    
+    
     public void interactiveRevalidateOnZoomable() {
         final JXMonthView monthView = new JXMonthView();
+        final Font font = monthView.getFont();
         JXFrame frame = wrapInFrame(monthView, "Revalidate on zoomable");
         Action toggleBackground = new AbstractAction("toggleZoomable") {
             
@@ -99,6 +177,19 @@ public class JXMonthViewVisualCheck extends InteractiveTestCase {
             
         };
         addAction(frame, toggleTraversable);
+        Action toggleFont = new AbstractAction("toggleFont") {
+            
+            public void actionPerformed(ActionEvent e) {
+                
+                if (monthView.getFont().isItalic()) {
+                    monthView.setFont(font);
+                } else {
+                    monthView.setFont(font.deriveFont(Font.ITALIC));
+                }
+            }
+            
+        };
+        addAction(frame, toggleFont);
         show(frame);
 
     }
@@ -108,11 +199,13 @@ public class JXMonthViewVisualCheck extends InteractiveTestCase {
      * look for
      * - selectionBackground
      * - selectionForeground (not taken?)
-     * 
+     * - flaggedDateForeground
+     * - componentOrientation (duplicate #996-swingx)
      * 
      */
     public void interactiveRepaintOnPropertyChange() {
         final JXMonthView monthView = new JXMonthView();
+        final Font font = monthView.getFont();
         monthView.setSelectionDate(CalendarUtils.startOfWeek(calendar, new Date()));
         monthView.setFlaggedDates(CalendarUtils.endOfWeek(calendar, new Date()));
         final Color selectionBackground = monthView.getSelectionBackground();
@@ -151,6 +244,42 @@ public class JXMonthViewVisualCheck extends InteractiveTestCase {
             
         };
         addAction(frame, toggleFlaggedForeground);
+        
+        Action toggleCO = new AbstractAction("toggleCO") {
+            
+            public void actionPerformed(ActionEvent e) {
+                
+                if (monthView.getComponentOrientation().isLeftToRight()) {
+                    monthView.setComponentOrientation(ComponentOrientation.RIGHT_TO_LEFT);
+                } else {
+                    monthView.setComponentOrientation(ComponentOrientation.LEFT_TO_RIGHT);
+                    
+                }
+            }
+            
+        };
+        addAction(frame, toggleCO);
+        Action toggleFont = new AbstractAction("toggleFont") {
+            
+            public void actionPerformed(ActionEvent e) {
+                
+                if (monthView.getFont().isItalic()) {
+                    monthView.setFont(font);
+                } else {
+                    monthView.setFont(font.deriveFont(Font.ITALIC));
+                }
+            }
+            
+        };
+        addAction(frame, toggleFont);
+        Action toggleEnabled = new AbstractAction("toggleEnabled") {
+            
+            public void actionPerformed(ActionEvent e) {
+                monthView.setEnabled(!monthView.isEnabled());
+            }
+            
+        };
+        addAction(frame, toggleEnabled);
         show(frame);
         
     }
@@ -186,7 +315,16 @@ public class JXMonthViewVisualCheck extends InteractiveTestCase {
         final JXMonthView monthView = new JXMonthView(); 
         monthView.setTraversable(true);
         final JXFrame frame = showInFrame(monthView, "MonthView - click property and see the change");
-        Action action = new AbstractActionExt("today flag") {
+        final Calendar calendar = monthView.getCalendar();
+        calendar.add(Calendar.DATE, 5);
+        Action unselectable = new AbstractActionExt("lowerbound") {
+            public void actionPerformed(ActionEvent e) {
+                monthView.setLowerBound(monthView.getLowerBound() == null ? calendar.getTime() : null);
+            }
+            
+        };
+        addAction(frame, unselectable);
+       Action action = new AbstractActionExt("today flag") {
             public void actionPerformed(ActionEvent e) {
                 if (monthView.hasFlaggedDates()) {
                     monthView.clearFlaggedDates();
@@ -339,7 +477,7 @@ public class JXMonthViewVisualCheck extends InteractiveTestCase {
         final JXMonthView monthView = new JXMonthView(); 
         monthView.setTraversable(true);
         final JXFrame frame = showInFrame(monthView, "MonthView today");
-        Action action = new AbstractActionExt("increment today") {
+        Action action = new AbstractActionExt("increment today - programmatically") {
             public void actionPerformed(ActionEvent e) {
                 monthView.incrementToday();
             }
@@ -555,7 +693,38 @@ public class JXMonthViewVisualCheck extends InteractiveTestCase {
      * timezones.
      * 
      */
-    public void interactiveUpdateOnTimeZone() {
+    public void interactiveUpdateTodayOnSetTimeZone() {
+        JComponent panel = Box.createVerticalBox();
+        
+        final JComboBox zoneSelector = new JComboBox(TimeZone.getAvailableIDs());
+        final JXMonthView monthView = new JXMonthView();
+        monthView.setTraversable(true);
+        // Synchronize the picker and selector's zones.
+        zoneSelector.setSelectedItem(monthView.getTimeZone().getID());
+        
+        // Set the picker's time zone based on the selected time zone.
+        zoneSelector.addActionListener(new ActionListener() {
+            public void actionPerformed(ActionEvent event) {
+                String zone = (String) zoneSelector.getSelectedItem();
+                TimeZone tz = TimeZone.getTimeZone(zone);
+                monthView.setTimeZone(tz);
+                
+                assertEquals(tz, monthView.getCalendar().getTimeZone());
+            }
+        });
+        
+        panel.add(monthView);
+        panel.add(zoneSelector);
+        showInFrame(panel, "today - on setTimeZone");
+    }
+    
+    /**
+     * Issue #618-swingx: JXMonthView displays problems with non-default
+     * timezones.
+     * Issue #1143-swingx: JXMonthView NPE on setTimeZone/setModel
+     * 
+     */
+    public void interactiveUpdateTodayOnSetModelTimeZone() {
         JComponent panel = Box.createVerticalBox();
 
         final JComboBox zoneSelector = new JComboBox(TimeZone.getAvailableIDs());
@@ -569,7 +738,9 @@ public class JXMonthViewVisualCheck extends InteractiveTestCase {
             public void actionPerformed(ActionEvent event) {
                 String zone = (String) zoneSelector.getSelectedItem();
                 TimeZone tz = TimeZone.getTimeZone(zone);
-                monthView.setTimeZone(tz);
+                DateSelectionModel model = new SingleDaySelectionModel();
+                model.setTimeZone(tz);
+                monthView.setSelectionModel(model);
               
                 assertEquals(tz, monthView.getCalendar().getTimeZone());
             }
@@ -577,7 +748,7 @@ public class JXMonthViewVisualCheck extends InteractiveTestCase {
 
         panel.add(monthView);
         panel.add(zoneSelector);
-        showInFrame(panel, "TimeZone");
+        showInFrame(panel, "today - on setModel with different TimeZone");
     }
     
     /**
@@ -742,8 +913,17 @@ public class JXMonthViewVisualCheck extends InteractiveTestCase {
      * 
      * Fixed as a side-effect of cleanup of input map bindings. 
      * 
+     * Regression #555 
+     * 
+     * Issue #996-swingx: NPE while dragging 
+     * 
+     * to reproduce: first click into a empty (leading/trailing) day then
+     * drag into month. Fixed (brutish? - not entirely sure as the user
+     * interaction is suboptimal anyway ..)
      */
     public void interactiveMultipleSelectionWithKeyboard() {
+        JXMonthView single = new JXMonthView();
+        single.setSelectionMode(SelectionMode.SINGLE_SELECTION);
         JXMonthView interval = new JXMonthView();
         interval.setSelectionMode(SelectionMode.SINGLE_INTERVAL_SELECTION);
         JXMonthView multiple = new JXMonthView();
@@ -751,14 +931,15 @@ public class JXMonthViewVisualCheck extends InteractiveTestCase {
         // for comparison: single interval in popup is working
         JXDatePicker picker = new JXDatePicker();
         JXMonthView intervalForPicker = new JXMonthView();
-        intervalForPicker.setSelectionMode(SelectionMode.SINGLE_INTERVAL_SELECTION);
+        intervalForPicker.setSelectionMode(SelectionMode.MULTIPLE_INTERVAL_SELECTION);
         picker.setMonthView(intervalForPicker);
         
         JComponent comp = new JPanel();
+        comp.add(single);
         comp.add(interval);
         comp.add(multiple);
         comp.add(picker);
-        showInFrame(comp, "select interval with keyboard");
+        showInFrame(comp, "select interval with keyboard: single vs. singleInt vs. multipleInt");
         
     }
     /**
