@@ -1,5 +1,5 @@
 /*
- * $Id: JXTreeTableIssues.java,v 1.79 2008/12/23 18:12:36 kschaefe Exp $
+ * $Id: JXTreeTableIssues.java 3512 2009-09-22 07:54:02Z kleopatra $
  * 
  * Copyright 2004 Sun Microsystems, Inc., 4150 Network Circle, Santa Clara,
  * California 95054, U.S.A. All rights reserved.
@@ -31,6 +31,8 @@ import java.util.logging.Logger;
 import javax.swing.AbstractAction;
 import javax.swing.Action;
 import javax.swing.BorderFactory;
+import javax.swing.DefaultCellEditor;
+import javax.swing.JComboBox;
 import javax.swing.JFrame;
 import javax.swing.JTree;
 import javax.swing.SwingUtilities;
@@ -47,7 +49,7 @@ import javax.swing.tree.TreePath;
 import org.jdesktop.swingx.action.AbstractActionExt;
 import org.jdesktop.swingx.decorator.Highlighter;
 import org.jdesktop.swingx.decorator.HighlighterFactory;
-import org.jdesktop.swingx.hyperlink.LinkAction;
+import org.jdesktop.swingx.hyperlink.AbstractHyperlinkAction;
 import org.jdesktop.swingx.renderer.CellContext;
 import org.jdesktop.swingx.renderer.CheckBoxProvider;
 import org.jdesktop.swingx.renderer.ComponentProvider;
@@ -70,7 +72,6 @@ import org.jdesktop.swingx.treetable.FileSystemModel;
 import org.jdesktop.swingx.treetable.MutableTreeTableNode;
 import org.jdesktop.swingx.treetable.TreeTableModel;
 import org.jdesktop.swingx.treetable.TreeTableNode;
-import org.jdesktop.test.AncientSwingTeam;
 import org.jdesktop.test.TableModelReport;
 
 /**
@@ -93,10 +94,10 @@ public class JXTreeTableIssues extends InteractiveTestCase {
         JXTreeTableIssues test = new JXTreeTableIssues();
         try {
 //            test.runInteractiveTests();
-//            test.runInteractiveTests(".*ColumnSelection.*");
+            test.runInteractiveTests(".*Combo.*");
 //            test.runInteractiveTests(".*Text.*");
 //            test.runInteractiveTests(".*TreeExpand.*");
-            test.runInteractiveTests("interactive.*Cancel.*");
+//            test.runInteractiveTests("interactive.*EditWith.*");
 //          test.runInteractiveTests("interactive.*CustomColor.*");
               
         } catch (Exception e) {
@@ -105,18 +106,29 @@ public class JXTreeTableIssues extends InteractiveTestCase {
         }
     }
 
+    
     /**
-     * Issue #875-swingx: cell selection incorrect in hierarchical column.
+     * Issue #??: combo editor is closed immediately after starting
      * 
+     * Happens if row is not selected at the moment of starting, okay if selected.
+     * Inserts on pressed, removes on released. Same for 1.5 and 1.6
      */
-    public void interactiveColumnSelection() {
-        JXTreeTable treeTable = new JXTreeTable(new FileSystemModel());
-        treeTable.setColumnSelectionAllowed(true);
-        JXTable table = new JXTable(new AncientSwingTeam());
-        table.setColumnSelectionAllowed(true);
-        JXFrame frame = wrapWithScrollingInFrame(treeTable, table, "columnSelection in treetable");
-        show(frame);
+    public void interactiveEditWithComboBox() {
+        // quick for having an editable treeTableModel (non hierarchical column)
+        TreeTableModel model = new ComponentTreeTableModel(new JXFrame());
+        JXTreeTable treeTable = new JXTreeTable(model);
+        treeTable.expandAll();
+        JComboBox box = new JComboBox(new Object[] {200, 300, 400});
+        box.setEditable(true);
+        treeTable.getColumn(3).setCellEditor(new DefaultCellEditor(box));
+        JXTable table = new JXTable(treeTable.getModel());
+        JComboBox box2 = new JComboBox(new Object[] {200, 300, 400});
+        box2.setEditable(true);
+        table.getColumn(3).setCellEditor(new DefaultCellEditor(box2));
+        showWithScrollingInFrame(treeTable, table, "combo editor in column 3");
     }
+    
+
     /**
      * Custom renderer colors of Swingx DefaultTreeRenderer not respected.
      * (same in J/X/Tree). 
@@ -678,7 +690,7 @@ public class JXTreeTableIssues extends InteractiveTestCase {
      * 
      */
     public void interactiveTreeTableLinkRendererSimpleText() {
-        LinkAction simpleAction = new LinkAction<Object>(null) {
+        AbstractHyperlinkAction<Object> simpleAction = new AbstractHyperlinkAction<Object>(null) {
 
             public void actionPerformed(ActionEvent e) {
                 LOG.info("hit: " + getTarget());
@@ -731,7 +743,7 @@ public class JXTreeTableIssues extends InteractiveTestCase {
             }
             
         };
-        ComponentProvider provider = new CheckBoxProvider(sv);
+        ComponentProvider<?> provider = new CheckBoxProvider(sv);
 //            /**
 //             * custom tooltip: show row. Note: the context is that 
 //             * of the rendering tree. No way to get at table state?
@@ -844,7 +856,7 @@ public class JXTreeTableIssues extends InteractiveTestCase {
             }
 
         };
-        ComponentProvider tableProvider = new LabelProvider(format);
+        ComponentProvider<?> tableProvider = new LabelProvider(format);
         WrappingProvider wrappingProvider = new WrappingProvider(tableProvider) {
             Border redBorder = BorderFactory.createLineBorder(Color.RED);
 
@@ -970,7 +982,7 @@ public class JXTreeTableIssues extends InteractiveTestCase {
      */
     public void interactiveTreeTableGetValueRenderer() {
         JXTreeTable tree = new JXTreeTable(new ComponentTreeTableModel(new JXFrame()));
-        ComponentProvider provider = new CheckBoxProvider(StringValues.TO_STRING) {
+        ComponentProvider<?> provider = new CheckBoxProvider(StringValues.TO_STRING) {
             
             @Override
             protected String getValueAsString(CellContext context) {
