@@ -1,5 +1,5 @@
 /*
- * $Id: JXTreeTableUnitTest.java,v 1.64 2008/12/23 18:12:37 kschaefe Exp $
+ * $Id: JXTreeTableUnitTest.java 3494 2009-09-07 14:31:02Z kleopatra $
  * 
  * Copyright 2004 Sun Microsystems, Inc., 4150 Network Circle, Santa Clara,
  * California 95054, U.S.A. All rights reserved.
@@ -20,6 +20,8 @@
  */
 package org.jdesktop.swingx;
 
+import static org.junit.Assert.*;
+
 import java.awt.Color;
 import java.awt.Component;
 import java.awt.Point;
@@ -30,14 +32,15 @@ import java.lang.reflect.InvocationTargetException;
 import java.util.Vector;
 import java.util.logging.Logger;
 
-import javax.swing.DefaultListSelectionModel;
 import javax.swing.JLabel;
 import javax.swing.JPanel;
+import javax.swing.JTable;
 import javax.swing.JTextField;
 import javax.swing.SwingUtilities;
 import javax.swing.event.TableModelEvent;
 import javax.swing.event.TreeSelectionEvent;
 import javax.swing.table.TableModel;
+import javax.swing.table.TableRowSorter;
 import javax.swing.tree.DefaultTreeCellRenderer;
 import javax.swing.tree.DefaultTreeModel;
 import javax.swing.tree.TreePath;
@@ -58,14 +61,12 @@ import org.jdesktop.swingx.treetable.TreeTableNode;
 import org.jdesktop.test.AncientSwingTeam;
 import org.jdesktop.test.PropertyChangeReport;
 import org.jdesktop.test.TableModelReport;
+import org.jdesktop.test.TreeExpansionReport;
 import org.jdesktop.test.TreeSelectionReport;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.junit.runners.JUnit4;
-import org.junit.Test;
-import org.junit.Before;
-import org.junit.After;
 
 
 @RunWith(JUnit4.class)
@@ -81,8 +82,92 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
         super("JXTreeTable Unit Test");
     }
 
+    /**
+     * Issue #876-swingx: add support for adding/removing expansion listeners.
+     */
+    @Test
+    public void testExpansionListenerSourceExpanded() {
+        JXTreeTable table = new JXTreeTable(new FileSystemModel());
+        TreeExpansionReport report = new TreeExpansionReport(table);
+        table.expandRow(0);
+        assertEquals(1, report.getEventCount());
+        assertEquals(table, report.getLastExpandedEvent().getSource());
+    }
+    /**
+     * Issue #876-swingx: add support for adding/removing expansion listeners.
+     */
+    @Test
+    public void testExpansionListenerSourceCollapsed() {
+        JXTreeTable table = new JXTreeTable(new FileSystemModel());
+        table.expandRow(0);
+        TreeExpansionReport report = new TreeExpansionReport(table);
+        table.collapseRow(0);
+        assertEquals(1, report.getEventCount());
+        assertEquals(table, report.getLastCollapsedEvent().getSource());
+    }
     
     /**
+     * Part of issue ??-swingx: tree width must be same as hierarchical column width
+     */
+    @Test
+    public void testTreeWidth() {
+        JXTreeTable table = new JXTreeTable(new FileSystemModel());
+        table.setAutoResizeMode(JTable.AUTO_RESIZE_OFF);
+        JXTree tree = (JXTree) table.getCellRenderer(0, 0);
+        int old = table.getColumn(0).getWidth();
+        assertEquals(old, tree.getWidth());
+        int width = old *2;
+        table.getColumn(0).setWidth(width);
+        assertEquals(width, table.getColumn(0).getWidth());
+        assertEquals(width, tree.getWidth());
+    }
+    
+    /**
+     * Issue #1121: most not be sortable
+     * 
+     * Here: test that the autoCreateRowSorter property is false.
+     */
+    @Test
+    public void testAutoCreateRowSorterDisabled() {
+        JXTreeTable table = new JXTreeTable();
+        assertEquals("treeTable autoCreateRowSorter must be false", false, table.getAutoCreateRowSorter());
+    }
+    /**
+     * Issue #1121: most not be sortable
+     * 
+     * Here: test that the autoCreateRowSorter property is not settable.
+     */
+    @Test
+    public void testAutoCreateRowSorterNotSettable() {
+        JXTreeTable table = new JXTreeTable();
+        table.setAutoCreateRowSorter(true);
+        assertEquals("treeTable autoCreateRowSorter must be false", false, table.getAutoCreateRowSorter());
+    }
+
+    /**
+     * Issue #1121: most not be sortable
+     * 
+     * Here: test that the no rowSorter installed.
+     */
+    @Test
+    public void testRowSorterNull() {
+        JXTreeTable table = new JXTreeTable();
+        assertNull("null rowsorter initially, was: " + table.getRowSorter(),
+                table.getRowSorter());
+    }
+    /**
+     * Issue #1121: most not be sortable
+     * 
+     * Here: test that the no rowSorter installed.
+     */
+    @Test
+    public void testRowSorterNotSettable() {
+        JXTreeTable table = new JXTreeTable();
+        table.setRowSorter(new TableRowSorter<TableModel>());
+        assertNull("rowsorter not settable, was: " + table.getRowSorter(), 
+                table.getRowSorter());
+    }
+/**
      * Issue #766-swingx: drop image is blinking over hierarchical column.
      * 
      * Test the hack - enabled by default, can be disabled by setting the
@@ -251,35 +336,6 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
     }
     
 
-    /**
-     * Issue 746-swingx: treetable selectionMapper must not be static.
-     * 
-     * Here: test that different treetables have different instances of mapper.
-     */
-    @Test
-    public void testSelectionMapperViewSelectionModel() {
-        JXTreeTable one = new JXTreeTable();
-        assertSame("mapper's viewselectionModel must be same as the treetable's", 
-                one.getSelectionModel(), one.getSelectionMapper().getViewSelectionModel());
-        DefaultListSelectionModel selectionModel = new DefaultListSelectionModel();
-        one.setSelectionModel(selectionModel);
-        assertSame("mapper's viewselectionModel must be reset to new", 
-                selectionModel, one.getSelectionMapper().getViewSelectionModel());
-    }
-    
-    
-    /**
-     * Issue 746-swingx: treetable selectionMapper must not be static.
-     * 
-     * Here: test that different treetables have different instances of mapper.
-     */
-    @Test
-    public void testSelectionMapper() {
-        JXTreeTable one = new JXTreeTable();
-        JXTreeTable two = new JXTreeTable();
-        assertNotSame("treetables must not share the selectionMapper", 
-                one.getSelectionMapper(), two.getSelectionMapper());
-    }
     /**
      * #561-swingx: KeyEvent on hierarchical column doesn't start editing.
      * 
@@ -983,6 +1039,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
      * Issue #168-jdnc: dnd enabled breaks node collapse/expand.
      * testing auto-detection of dragHackEnabled.
      * 
+     * Removed auto-detection (cleanup 1.6)
      */
     @Test
     public void testDragHackFlagOn() {
@@ -991,14 +1048,15 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
         treeTable.getTreeTableHacker().expandOrCollapseNode(0, 
                 new MouseEvent(treeTable, MouseEvent.MOUSE_PRESSED, 0, InputEvent.BUTTON1_MASK, 0, 0, 1, false));
         Boolean dragHackFlag = (Boolean) treeTable.getClientProperty(JXTreeTable.DRAG_HACK_FLAG_KEY);
-        assertNotNull(dragHackFlag);
-        assertTrue(dragHackFlag);
+        assertNull(dragHackFlag);
     }
 
     /**
      * Issue #168-jdnc: dnd enabled breaks node collapse/expand.
      * testing auto-detection of dragHackEnabled.
      * 
+     * Removed auto-detection (cleanup 1.6)
+     * 
      */
     @Test
     public void testDragHackFlagOff() {
@@ -1008,8 +1066,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
         treeTable.getTreeTableHacker().expandOrCollapseNode(0, 
                 new MouseEvent(treeTable, MouseEvent.MOUSE_PRESSED, 0, InputEvent.BUTTON1_MASK, 0, 0, 1, false));
         Boolean dragHackFlag = (Boolean) treeTable.getClientProperty(JXTreeTable.DRAG_HACK_FLAG_KEY);
-        assertNotNull(dragHackFlag);
-        assertFalse(dragHackFlag);
+        assertNull(dragHackFlag);
         System.getProperties().remove("sun.swing.enableImprovedDragGesture");
     }
 
