@@ -1,5 +1,5 @@
 /*
- * $Id: JXTreeTableVisualCheck.java,v 1.73 2008/10/14 12:52:02 kleopatra Exp $
+ * $Id: JXTreeTableVisualCheck.java 3492 2009-09-07 09:40:19Z kleopatra $
  * 
  * Copyright 2004 Sun Microsystems, Inc., 4150 Network Circle, Santa Clara,
  * California 95054, U.S.A. All rights reserved.
@@ -34,8 +34,10 @@ import java.util.regex.Pattern;
 
 import javax.swing.AbstractAction;
 import javax.swing.Action;
+import javax.swing.Box;
 import javax.swing.CellEditor;
 import javax.swing.Icon;
+import javax.swing.JButton;
 import javax.swing.JComboBox;
 import javax.swing.JComponent;
 import javax.swing.JFrame;
@@ -61,21 +63,18 @@ import org.jdesktop.swingx.action.AbstractActionExt;
 import org.jdesktop.swingx.decorator.AbstractHighlighter;
 import org.jdesktop.swingx.decorator.ColorHighlighter;
 import org.jdesktop.swingx.decorator.ComponentAdapter;
-import org.jdesktop.swingx.decorator.Filter;
-import org.jdesktop.swingx.decorator.FilterPipeline;
 import org.jdesktop.swingx.decorator.HighlightPredicate;
 import org.jdesktop.swingx.decorator.Highlighter;
 import org.jdesktop.swingx.decorator.HighlighterFactory;
-import org.jdesktop.swingx.decorator.PatternFilter;
 import org.jdesktop.swingx.decorator.PatternPredicate;
 import org.jdesktop.swingx.decorator.ShadingColorHighlighter;
-import org.jdesktop.swingx.decorator.ShuttleSorter;
 import org.jdesktop.swingx.decorator.HighlightPredicate.AndHighlightPredicate;
 import org.jdesktop.swingx.decorator.HighlightPredicate.ColumnHighlightPredicate;
 import org.jdesktop.swingx.decorator.HighlightPredicate.DepthHighlightPredicate;
 import org.jdesktop.swingx.renderer.DefaultTreeRenderer;
 import org.jdesktop.swingx.test.ComponentTreeTableModel;
 import org.jdesktop.swingx.test.XTestUtils;
+import org.jdesktop.swingx.treetable.AbstractTreeTableModel;
 import org.jdesktop.swingx.treetable.DefaultMutableTreeTableNode;
 import org.jdesktop.swingx.treetable.DefaultTreeTableModel;
 import org.jdesktop.swingx.treetable.FileSystemModel;
@@ -99,17 +98,78 @@ public class JXTreeTableVisualCheck extends JXTreeTableUnitTest {
 //            test.runInteractiveTests();
 //            test.runInteractiveTests("interactive.*Hierarchical.*");
 //               test.runInteractiveTests("interactive.*ToolTip.*");
-//           test.runInteractiveTests("interactive.*DnD.*");
-//             test.runInteractiveTests("interactive.*Compare.*");
+           test.runInteractiveTests("interactive.*DnD.*");
+             test.runInteractiveTests("interactive.*ColumnSelection.*");
 //             test.runInteractiveTests("interactive.*RowHeightCompare.*");
-//             test.runInteractiveTests("interactive.*RToL.*");
+             test.runInteractiveTests("interactive.*RToL.*");
 //             test.runInteractiveTests("interactive.*Insert.*");
-             test.runInteractiveTests("interactive.*Selection.*");
+//             test.runInteractiveTests("interactive.*WinP.*");
         } catch (Exception ex) {
 
         }
     }
 
+    /**
+     * Issue #875-swingx: cell selection incorrect in hierarchical column.
+     * 
+     */
+    public void interactiveColumnSelection() {
+        final JXTreeTable treeTable = new JXTreeTable(new FileSystemModel());
+        treeTable.setColumnSelectionAllowed(true);
+        final JTable table = new JTable(new AncientSwingTeam());
+        table.setColumnSelectionAllowed(true);
+        JXFrame frame = wrapWithScrollingInFrame(treeTable, table, "columnSelection in treetable");
+        Action action = new AbstractActionExt("Toggle dnd: false") {
+
+            public void actionPerformed(ActionEvent e) {
+                
+                boolean dragEnabled = !treeTable.getDragEnabled();
+                treeTable.setDragEnabled(dragEnabled);
+                table.setDragEnabled(dragEnabled);
+                setName("Toggle dnd: " + dragEnabled);
+            }
+            
+        };
+        addAction(frame, action);
+        show(frame);
+    }
+
+    /**
+     * Performance problems with Windows LAF.
+     */
+    public void interactiveTreeTableWinPerformance() {
+        JXTreeTable table = new JXTreeTable(new SimpleTestModel());
+        showWithScrollingInFrame(table, "JXTreeTable (performance in win");
+    }
+    public static class SimpleTestModel extends AbstractTreeTableModel {
+        private static final String root = "Root";
+ 
+        public SimpleTestModel() {
+            super(root);
+        }
+ 
+        public int getColumnCount() {
+            return 4;
+        }
+ 
+        public Object getValueAt(Object o, int i) {
+            return o + ":" + i;
+        }
+ 
+        public Object getChild(Object parent, int index) {
+            return parent == root ? String.valueOf(index) : null;
+        }
+ 
+        public int getChildCount(Object parent) {
+            return parent == root ? 10000 : 0;
+        }
+ 
+        public int getIndexOfChild(Object parent, Object child) {
+            return parent == root ? Integer.valueOf((String) child) : -1;
+        }
+    }
+
+
 
     
     /**
@@ -341,8 +401,6 @@ public class JXTreeTableVisualCheck extends JXTreeTableUnitTest {
      *
      */
     public void interactiveLargeModel() {
-//        final JXTreeTable treeTable = new JXTreeTable(treeTableModel); 
-
         final JXTreeTable treeTable = new JXTreeTable(createMutableVisualizeModel());
         treeTable.setRootVisible(true);
         ToolTipManager.sharedInstance().unregisterComponent(treeTable);
@@ -365,9 +423,17 @@ public class JXTreeTableVisualCheck extends JXTreeTableUnitTest {
         JTextField textField = new JTextField();
         textField.setName("firstchild");
         frame.add(textField);
-        frame.add(textField);
+        JComponent box = Box.createVerticalBox();
+        box.setName("dumyybox");
+        frame.add(box);
+        JComponent inner = Box.createHorizontalBox();
+        inner.setName("inner");
+        box.add(inner);
+        inner.add(new JButton());
+        inner.add(new JXFindPanel());
         frame.add(new JComboBox());
         frame.add(new JXDatePicker());
+        
         return new ComponentTreeTableModel(frame);
     }
 
@@ -786,9 +852,20 @@ public class JXTreeTableVisualCheck extends JXTreeTableUnitTest {
     public void interactiveRToLTreeTableEditor() {
         final TreeTableModel model = createMutableVisualizeModel();
         final JXTreeTable table = new JXTreeTable(model);
-        final JXFrame frame = wrapWithScrollingInFrame(table, "Editor: position follows Component orientation");
+        table.expandAll();
+        
+        final JXFrame frame = wrapWithScrollingInFrame(table, new JTable(table.getModel()),
+                "Editor: position follows Component orientation");
         addComponentOrientationToggle(frame);
-        frame.setVisible(true);
+        Action edit = new AbstractAction("edit 1/1") {
+            
+            @Override
+            public void actionPerformed(ActionEvent e) {
+                table.editCellAt(1, 1);
+            }
+        };
+        addAction(frame, edit);
+        show(frame);
     }
 
     /**
@@ -1096,35 +1173,6 @@ public class JXTreeTableVisualCheck extends JXTreeTableUnitTest {
     }
 
     
-    /**
-     * Issue #204: weird filtering.
-     *
-     */
-    public void interactiveTestFilters() {
-        JXTreeTable treeTable = new JXTreeTable(treeTableModel);
-        treeTable.putClientProperty("JTree.lineStyle", "Angled");
-        treeTable.setRowHeight(22);
-        treeTable.setFilters(new FilterPipeline(new Filter[] {
-                new PatternFilter( "^d",
-                        Pattern.CASE_INSENSITIVE, 0), }));
-        JFrame frame = wrapWithScrollingInFrame(treeTable,
-                "PatternFilter");
-        frame.setVisible(true);
-    }
-    
-    /**
-     * Issue #??: weird sorting.
-     *
-     */
-    public void interactiveTestSortingFilters() {
-        JXTreeTable treeTable = new JXTreeTable(treeTableModel);
-        treeTable.setRowHeight(22);
-        treeTable.setFilters(new FilterPipeline(new Filter[] {
-                new ShuttleSorter(1, false), }));
-        JFrame frame = wrapWithScrollingInFrame(treeTable,
-                "SortingFilter");
-        frame.setVisible(true);
-    }
     
     
     public void interactiveTestHighlightAndRowHeight() {
