@@ -1,5 +1,5 @@
 /*
- * $Id: JXTreeUnitTest.java,v 1.35 2008/12/23 18:12:36 kschaefe Exp $
+ * $Id: JXTreeUnitTest.java 3464 2009-08-24 10:31:14Z kleopatra $
  *
  * Copyright 2004 Sun Microsystems, Inc., 4150 Network Circle,
  * Santa Clara, California 95054, U.S.A. All rights reserved.
@@ -16,6 +16,7 @@ import javax.swing.tree.DefaultMutableTreeNode;
 import javax.swing.tree.DefaultTreeCellEditor;
 import javax.swing.tree.DefaultTreeCellRenderer;
 import javax.swing.tree.DefaultTreeModel;
+import javax.swing.tree.TreeCellEditor;
 import javax.swing.tree.TreeCellRenderer;
 import javax.swing.tree.TreePath;
 
@@ -29,17 +30,16 @@ import org.jdesktop.swingx.renderer.DefaultTreeRenderer;
 import org.jdesktop.swingx.renderer.StringValue;
 import org.jdesktop.swingx.renderer.StringValues;
 import org.jdesktop.swingx.tree.DefaultXTreeCellEditor;
+import org.jdesktop.swingx.tree.DefaultXTreeCellRenderer;
 import org.jdesktop.swingx.treetable.DefaultMutableTreeTableNode;
 import org.jdesktop.swingx.treetable.FileSystemModel;
 import org.jdesktop.swingx.treetable.TreeTableModel;
 import org.jdesktop.test.AncientSwingTeam;
 import org.jdesktop.test.PropertyChangeReport;
 import org.jdesktop.test.TestUtils;
+import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.junit.runners.JUnit4;
-import org.junit.Test;
-import org.junit.Before;
-import org.junit.After;
 
 
 
@@ -57,6 +57,75 @@ public class JXTreeUnitTest extends InteractiveTestCase {
         super("JXTree Test");
     }
 
+    /**
+     * Issue #1061-swingx: renderer/editor inconsistent on startup
+     */
+    @Test
+    public void testRendererOnInit() {
+        TestTree tree = new TestTree();
+        assertSame(tree.getSuperRenderer(), tree.getCellRenderer()); 
+    }
+
+    /**
+     * Issue #1061-swingx: renderer/editor inconsistent on startup
+     */
+    @Test
+    public void testEditorOnInit() {
+        TestTree tree = new TestTree();
+        assertSame(tree.getSuperEditor(), tree.getCellEditor()); 
+    }
+    
+    /**
+     * Issue #1061-swingx: renderer/editor inconsistent on startup
+     */
+    @Test
+    public void testDefaultRendererOnInit() {
+        TestTree tree = new TestTree();
+        assertNotNull("sanity: default renderer created", tree.getCreatedDefaultRenderer()); 
+        assertSame("sanity: default renderer used as wrappee", tree.getCreatedDefaultRenderer(), tree.getWrappedCellRenderer());
+    }
+    
+    /**
+     * Issue #1061-swingx: renderer/editor inconsistent on startup.
+     * Note: this test will fail once we use an enhanced cellEditor (which can cope with 
+     * SwingX default renderers).
+     */
+    @Test
+    public void testDefaultRendererUsedInEditorOnInit() {
+        TestTree tree = new TestTree();
+        assertTrue("sanity: editor is of type DefaultXTreeCellEditor", tree.getCellEditor() instanceof DefaultXTreeCellEditor);
+        assertSame(tree.getWrappedCellRenderer(), ((DefaultXTreeCellEditor) tree.getCellEditor()).getRenderer()); 
+    }
+    
+    
+    /**
+     * Subclass for testing: access cellRenderer/cellEditor fields 
+     */
+    public static class TestTree extends JXTree {
+        
+        private TreeCellRenderer createdDefaultRenderer;
+
+        public TreeCellRenderer getSuperRenderer() {
+            return cellRenderer;
+        }
+        
+        public TreeCellEditor getSuperEditor() {
+            return cellEditor;
+        }
+
+        public TreeCellRenderer getCreatedDefaultRenderer() {
+            return createdDefaultRenderer;
+        }
+        
+        @Override
+        protected TreeCellRenderer createDefaultCellRenderer() {
+            createdDefaultRenderer = super.createDefaultCellRenderer();
+            return createdDefaultRenderer;
+        }
+        
+        
+    }
+
     /**
      * Issue #862-swingx: JXTree - add api for selection colors.
      */
@@ -164,7 +233,7 @@ public class JXTreeUnitTest extends InteractiveTestCase {
     public void testDelegatingRendererUseDefault() {
         JXTree list = new JXTree();
         TreeCellRenderer defaultRenderer = list.createDefaultCellRenderer();
-        assertEquals("sanity: creates default", DefaultTreeCellRenderer.class, 
+        assertEquals("sanity: creates default", DefaultXTreeCellRenderer.class, 
                 defaultRenderer.getClass());
         DelegatingRenderer renderer = (DelegatingRenderer) list.getCellRenderer();
         assertEquals(defaultRenderer.getClass(), renderer.getDelegateRenderer().getClass());
@@ -530,6 +599,8 @@ public class JXTreeUnitTest extends InteractiveTestCase {
         ComponentAdapter adapter = list.getComponentAdapter();
         assertEquals(0, adapter.column);
         assertEquals(0, adapter.row);
+        assertTrue(adapter.isHierarchical());
+        
         adapter.row = 1;
         // corrupt adapter
         adapter.column = 1;
@@ -600,8 +671,8 @@ public class JXTreeUnitTest extends InteractiveTestCase {
     public void testInitInConstructors() {
         assertXTreeInit(new JXTree());
         assertXTreeInit(new JXTree(new Object[] {}));
-        assertXTreeInit(new JXTree(new Vector()));
-        assertXTreeInit(new JXTree(new Hashtable()));
+        assertXTreeInit(new JXTree(new Vector<Object>()));
+        assertXTreeInit(new JXTree(new Hashtable<Object, Object>()));
         assertXTreeInit(new JXTree(new DefaultMutableTreeNode("dummy"), false));
         assertXTreeInit(new JXTree(new DefaultMutableTreeNode("dummy")));
         assertXTreeInit(new JXTree(new DefaultTreeModel(new DefaultMutableTreeNode("dummy"))));
