@@ -1,5 +1,5 @@
 /*
- * $Id: ComponentAdapterIssues.java,v 1.10 2008/12/23 18:12:38 kschaefe Exp $
+ * $Id: ComponentAdapterIssues.java 3473 2009-08-27 13:17:10Z kleopatra $
  *
  * Copyright 2006 Sun Microsystems, Inc., 4150 Network Circle,
  * Santa Clara, California 95054, U.S.A. All rights reserved.
@@ -22,14 +22,16 @@
 package org.jdesktop.swingx.decorator;
 
 import java.awt.Color;
+import java.util.logging.Logger;
 
 import org.jdesktop.swingx.InteractiveTestCase;
 import org.jdesktop.swingx.JXFrame;
 import org.jdesktop.swingx.JXTree;
 import org.jdesktop.swingx.JXTreeTable;
-import org.jdesktop.swingx.renderer.DefaultTreeRenderer;
 import org.jdesktop.swingx.renderer.StringValue;
 import org.jdesktop.swingx.renderer.StringValues;
+import org.jdesktop.swingx.search.SearchFactory;
+import org.jdesktop.swingx.test.ComponentTreeTableModel;
 import org.jdesktop.swingx.treetable.TreeTableModel;
 import org.jdesktop.test.AncientSwingTeam;
 
@@ -45,7 +47,11 @@ import org.jdesktop.test.AncientSwingTeam;
  */
 public class ComponentAdapterIssues extends InteractiveTestCase {
 
+    @SuppressWarnings("unused")
+    private static final Logger LOG = Logger
+            .getLogger(ComponentAdapterIssues.class.getName());
     public static void main(String[] args) {
+        SearchFactory.getInstance().setUseFindBar(true);
         ComponentAdapterIssues test = new ComponentAdapterIssues();
         try {
             test.runInteractiveTests();
@@ -67,9 +73,9 @@ public class ComponentAdapterIssues extends InteractiveTestCase {
         TreeTableModel model = AncientSwingTeam.createNamedColorTreeTableModel();
         JXTreeTable treeTable = new JXTreeTable(model);
         treeTable.setRootVisible(true);
-        treeTable.setTreeCellRenderer(new DefaultTreeRenderer(sv));
+//        treeTable.setTreeCellRenderer(new DefaultTreeRenderer(sv));
         JXTree tree =  new JXTree(model);
-        tree.setCellRenderer(new DefaultTreeRenderer(sv));
+//        tree.setCellRenderer(new DefaultTreeRenderer(sv));
         HighlightPredicate predicate = new PatternPredicate("R/G/B: -2", 0, PatternPredicate.ALL);
         ColorHighlighter hl = new ColorHighlighter(predicate, null, Color.RED);
         treeTable.addHighlighter(hl);
@@ -78,7 +84,53 @@ public class ComponentAdapterIssues extends InteractiveTestCase {
         show(frame);
     }
 
+    /**
+     * Issue ??-swingx: TreeTable doesn't return correct string value for hierarchical column.
+     * 
+     * This is probably a variant of not using the table's renderer (at least I expect it 
+     * to be solved then at the latest). In the meantime, might want to do something special
+     * for the hierarchical column?
+     */
+    public void interactiveTreeTableStringValueComponent() {
+        TreeTableModel model = new ComponentTreeTableModel(new JXFrame());
+        JXTreeTable treeTable = new JXTreeTable(model);
+        treeTable.setRootVisible(true);
+        treeTable.expandAll();
+        LOG.info(treeTable.getStringAt(3, 0));
+//        treeTable.setTreeCellRenderer(new DefaultTreeRenderer(sv));
+        JXTree tree =  new JXTree(model);
+//        tree.setCellRenderer(new DefaultTreeRenderer(sv));
+        HighlightPredicate predicate = new PatternPredicate("null", 0, PatternPredicate.ALL);
+        ColorHighlighter hl = new ColorHighlighter(predicate, null, Color.RED);
+        treeTable.addHighlighter(hl);
+        tree.addHighlighter(hl);
+        JXFrame frame = wrapWithScrollingInFrame( treeTable, "string rep in hierarchical column");
+        show(frame);
+    }
 
+    /**
+     * Issue ??-swingx: TreeTable doesn't return correct string value for hierarchical column.
+     * 
+     * This is probably a variant of not using the table's renderer (at least I expect it 
+     * to be solved then at the latest). In the meantime, might want to do something special
+     * for the hierarchical column?
+     */
+    public void interactiveTreeStringValueComponent() {
+        TreeTableModel model = new ComponentTreeTableModel(new JXFrame());
+        JXTreeTable treeTable = new JXTreeTable(model);
+        treeTable.setRootVisible(true);
+        treeTable.expandAll();
+        LOG.info(treeTable.getStringAt(3, 0));
+//        treeTable.setTreeCellRenderer(new DefaultTreeRenderer(sv));
+        JXTree tree =  new JXTree(model);
+//        tree.setCellRenderer(new DefaultTreeRenderer(sv));
+        HighlightPredicate predicate = new PatternPredicate("null", 0, PatternPredicate.ALL);
+        ColorHighlighter hl = new ColorHighlighter(predicate, null, Color.RED);
+        treeTable.addHighlighter(hl);
+        tree.addHighlighter(hl);
+        JXFrame frame = wrapWithScrollingInFrame( tree, "string rep in hierarchical column");
+        show(frame);
+    }
 
     /**
      * Creates and returns a StringValue which maps a Color to it's R/G/B rep, 
