@@ -1,5 +1,5 @@
 /*
- * $Id: HighlightPredicateTest.java,v 1.17 2008/03/03 17:18:40 kleopatra Exp $
+ * $Id: HighlightPredicateTest.java 3473 2009-08-27 13:17:10Z kleopatra $
  *
  * Copyright 2004 Sun Microsystems, Inc., 4150 Network Circle,
  * Santa Clara, California 95054, U.S.A. All rights reserved.
@@ -18,13 +18,22 @@ import java.util.regex.Pattern;
 import javax.swing.JLabel;
 
 import org.jdesktop.swingx.InteractiveTestCase;
-import org.jdesktop.swingx.RolloverProducer;
 import org.jdesktop.swingx.decorator.HighlightPredicate.AndHighlightPredicate;
 import org.jdesktop.swingx.decorator.HighlightPredicate.ColumnHighlightPredicate;
+import org.jdesktop.swingx.decorator.HighlightPredicate.DepthHighlightPredicate;
 import org.jdesktop.swingx.decorator.HighlightPredicate.EqualsHighlightPredicate;
 import org.jdesktop.swingx.decorator.HighlightPredicate.IdentifierHighlightPredicate;
 import org.jdesktop.swingx.decorator.HighlightPredicate.NotHighlightPredicate;
 import org.jdesktop.swingx.decorator.HighlightPredicate.OrHighlightPredicate;
+import org.jdesktop.swingx.decorator.HighlightPredicate.RowGroupHighlightPredicate;
+import org.jdesktop.swingx.decorator.HighlightPredicate.TypeHighlightPredicate;
+import org.jdesktop.swingx.rollover.RolloverProducer;
+import org.junit.After;
+import org.junit.Before;
+import org.junit.Test;
+import org.junit.runner.RunWith;
+import org.junit.runners.JUnit4;
+
 
 /**
  * 
@@ -32,6 +41,7 @@ import org.jdesktop.swingx.decorator.HighlightPredicate.OrHighlightPredicate;
  * 
  * @author Jeanette Winzenburg
  */
+@RunWith(JUnit4.class)
 public class HighlightPredicateTest extends InteractiveTestCase {
 
     
@@ -51,6 +61,16 @@ public class HighlightPredicateTest extends InteractiveTestCase {
     
     protected ColorHighlighter emptyHighlighter;
 
+    @Before
+    public void setUpJ4() throws Exception {
+        setUp();
+    }
+    
+    @After
+    public void tearDownJ4() throws Exception {
+        tearDown();
+    }
+    
     @Override
     protected void setUp() {
         backgroundNull = new JLabel("test");
@@ -73,11 +93,36 @@ public class HighlightPredicateTest extends InteractiveTestCase {
     }
 
     // ---------------- predefined predicate
+    
+    /**
+     * Issue #858-swingx: predefined focus predicate. 
+     * 
+     * Test the HAS_FOCUS predicate
+     */
+    @Test
+    public void testHasFocus() {
+        ComponentAdapter adapter = createComponentAdapter(allColored, true, true);
+        assertTrue("sanity", adapter.hasFocus());
+        assertEquals(adapter.hasFocus(), HighlightPredicate.HAS_FOCUS.isHighlighted(allColored, adapter));
+     }
  
+    /**
+     * Issue #858-swingx: predefined focus predicate. 
+     * 
+     * Test the HAS_FOCUS predicate
+     */
+    @Test
+    public void testNotHasFocus() {
+        ComponentAdapter adapter = createComponentAdapter(allColored, false);
+        assertFalse("sanity", adapter.hasFocus());
+        assertEquals(adapter.hasFocus(), HighlightPredicate.HAS_FOCUS.isHighlighted(allColored, adapter));
+     }
+    
     /**
      * test the IS_FOLDER predicate.
      *
      */
+    @Test
     public void testFolder() {
         ComponentAdapter adapter = createComponentAdapter(allColored, false);
         assertTrue(HighlightPredicate.IS_FOLDER.isHighlighted(allColored, adapter));
@@ -87,6 +132,7 @@ public class HighlightPredicateTest extends InteractiveTestCase {
      * test the IS_FOLDER predicate.
      *
      */
+    @Test
     public void testNotFolder() {
         ComponentAdapter adapter = createComponentAdapter(allColored, true);
         assertFalse(HighlightPredicate.IS_FOLDER.isHighlighted(allColored, adapter));
@@ -96,6 +142,7 @@ public class HighlightPredicateTest extends InteractiveTestCase {
      * test the IS_LEAF predicate.
      *
      */
+    @Test
     public void testLeaf() {
         ComponentAdapter adapter = createComponentAdapter(allColored, false);
         assertFalse(HighlightPredicate.IS_LEAF.isHighlighted(allColored, adapter));
@@ -105,6 +152,7 @@ public class HighlightPredicateTest extends InteractiveTestCase {
      * test the IS_LEAF predicate.
      *
      */
+    @Test
     public void testNotLeaf() {
         ComponentAdapter adapter = createComponentAdapter(allColored, true);
         assertTrue(HighlightPredicate.IS_LEAF.isHighlighted(allColored, adapter));
@@ -114,6 +162,7 @@ public class HighlightPredicateTest extends InteractiveTestCase {
      * Can't really test the unconditional predicates.
      *
      */
+    @Test
     public void testAlways() {
         ComponentAdapter adapter = createComponentAdapter(allColored, true);
         assertTrue(HighlightPredicate.ALWAYS.isHighlighted(allColored, adapter));
@@ -123,6 +172,7 @@ public class HighlightPredicateTest extends InteractiveTestCase {
      * Can't really test the unconditional predicates.
      *
      */
+    @Test
     public void testNever() {
         ComponentAdapter adapter = createComponentAdapter(allColored, true);
         assertFalse(HighlightPredicate.NEVER.isHighlighted(allColored, adapter));
@@ -132,6 +182,7 @@ public class HighlightPredicateTest extends InteractiveTestCase {
      * test the Editable predicate.
      *
      */
+    @Test
     public void testEditable() {
         ComponentAdapter adapter = createComponentAdapter(allColored, false, true);
         assertTrue(HighlightPredicate.EDITABLE.isHighlighted(allColored, adapter));
@@ -142,17 +193,29 @@ public class HighlightPredicateTest extends InteractiveTestCase {
      * test the ReadOnly predicate.
      *
      */
+    @Test
     public void testNotEditable() {
         ComponentAdapter adapter = createComponentAdapter(allColored, false, false);
         assertFalse(HighlightPredicate.EDITABLE.isHighlighted(allColored, adapter));
         assertTrue(HighlightPredicate.READ_ONLY.isHighlighted(allColored, adapter));
     }
     
+    /**
+     * test access the contained predicates
+     */
+    @Test
+    public void testNotProperty() {
+        HighlightPredicate inputPredicates = new IdentifierHighlightPredicate("t");
+        NotHighlightPredicate predicate = new NotHighlightPredicate(inputPredicates);
+        HighlightPredicate predicates = predicate.getHighlightPredicate();
+        assertSame(inputPredicates, predicates);
+    }
     
     /**
      * test the NOT predicate.
      *
      */
+    @Test
     public void testNot() {
         ComponentAdapter adapter = createComponentAdapter(allColored, true);
         HighlightPredicate notNever = new NotHighlightPredicate(HighlightPredicate.NEVER);
@@ -161,9 +224,37 @@ public class HighlightPredicateTest extends InteractiveTestCase {
         assertFalse(notAlways.isHighlighted(allColored, adapter));
     }
 
+    /**
+     * test access the contained predicates
+     */
+    @Test
+    public void testOrProperty() {
+        List<HighlightPredicate> inputPredicates = new ArrayList<HighlightPredicate>();
+        inputPredicates.add(HighlightPredicate.NEVER);
+        inputPredicates.add(new IdentifierHighlightPredicate("t"));
+        OrHighlightPredicate predicate = new OrHighlightPredicate(inputPredicates);
+        HighlightPredicate[] predicates = predicate.getHighlightPredicates();
+        assertEquals(inputPredicates.size(), predicates.length);
+        for (int i = 0; i < predicates.length; i++) {
+            assertSame(inputPredicates.get(i), predicates[i]);
+        }
+    }
+    
+    /**
+     * test that getPredicates return empty array if nothing contained.
+     */
+    @Test
+    public void testOrEmptyProperty() {
+        OrHighlightPredicate predicate = new OrHighlightPredicate();
+        HighlightPredicate[] predicates = predicate.getHighlightPredicates();
+        assertNotNull("array must not be null", predicates);
+        assertEquals(0, predicates.length);
+    }
+
     /**
      * test that empty array doesn't highlight. 
      */
+    @Test
     public void testOrEmpty() {
         ComponentAdapter adapter = createComponentAdapter(allColored, true);
         HighlightPredicate emptyArray = new OrHighlightPredicate();
@@ -175,6 +266,7 @@ public class HighlightPredicateTest extends InteractiveTestCase {
      * test the OR predicate array constructor. Boring as it is, is it complete?
      *
      */
+    @Test
     public void testOr() {
         ComponentAdapter adapter = createComponentAdapter(allColored, true);
         HighlightPredicate oneTrue = new OrHighlightPredicate(HighlightPredicate.ALWAYS);
@@ -193,6 +285,7 @@ public class HighlightPredicateTest extends InteractiveTestCase {
      * test the OR predicate collection constructor. Boring as it is, is it complete?
      *
      */
+    @Test
     public void testOrCollectionConstructor() {
         ComponentAdapter adapter = createComponentAdapter(allColored, true);
         List<HighlightPredicate> containsOneTrue = new ArrayList<HighlightPredicate>();
@@ -223,6 +316,7 @@ public class HighlightPredicateTest extends InteractiveTestCase {
      *   is null.
      *
      */
+    @Test
     public void testOrThrowsOnNullPredicates() {
         try {
             new OrHighlightPredicate((HighlightPredicate[]) null);
@@ -271,6 +365,7 @@ public class HighlightPredicateTest extends InteractiveTestCase {
      *   is null.
      *
      */
+    @Test
     public void testAndThrowsOnNullPredicates() {
         try {
             new AndHighlightPredicate((HighlightPredicate[]) null);
@@ -315,9 +410,37 @@ public class HighlightPredicateTest extends InteractiveTestCase {
 
     }
 
+    /**
+     * test access the contained predicates
+     */
+    @Test
+    public void testAndProperty() {
+        List<HighlightPredicate> inputPredicates = new ArrayList<HighlightPredicate>();
+        inputPredicates.add(HighlightPredicate.NEVER);
+        inputPredicates.add(new IdentifierHighlightPredicate("t"));
+        AndHighlightPredicate predicate = new AndHighlightPredicate(inputPredicates);
+        HighlightPredicate[] predicates = predicate.getHighlightPredicates();
+        assertEquals(inputPredicates.size(), predicates.length);
+        for (int i = 0; i < predicates.length; i++) {
+            assertSame(inputPredicates.get(i), predicates[i]);
+        }
+    }
+    
+    /**
+     * test that getPredicates return empty array if nothing contained.
+     */
+    @Test
+    public void testAndEmptyProperty() {
+        AndHighlightPredicate predicate = new AndHighlightPredicate();
+        HighlightPredicate[] predicates = predicate.getHighlightPredicates();
+        assertNotNull("array must not be null", predicates);
+        assertEquals(0, predicates.length);
+    }
+    
     /**
      * test that empty array doesn't highlight. 
      */
+    @Test
     public void testAndEmpty() {
         ComponentAdapter adapter = createComponentAdapter(allColored, true);
         HighlightPredicate emptyArray = new AndHighlightPredicate();
@@ -330,6 +453,7 @@ public class HighlightPredicateTest extends InteractiveTestCase {
      * test the AND predicate array constructor. Boring as it is, is it complete?
      *
      */
+    @Test
     public void testAnd() {
         ComponentAdapter adapter = createComponentAdapter(allColored, true);
         HighlightPredicate oneTrue = new AndHighlightPredicate(HighlightPredicate.ALWAYS);
@@ -348,6 +472,7 @@ public class HighlightPredicateTest extends InteractiveTestCase {
      * test the AND predicate collection constructor. Boring as it is, is it complete?
      *
      */
+    @Test
     public void testAndCollectionConstructor() {
         ComponentAdapter adapter = createComponentAdapter(allColored, true);
         List<HighlightPredicate> containsOneTrue = new ArrayList<HighlightPredicate>();
@@ -378,6 +503,7 @@ public class HighlightPredicateTest extends InteractiveTestCase {
      * test rollover
      *
      */
+    @Test
     public void testRolloverRow() {
         ComponentAdapter adapter = createComponentAdapter(allColored, true);
         // rollover and adapter at 0, 0
@@ -397,6 +523,7 @@ public class HighlightPredicateTest extends InteractiveTestCase {
      * Issue #513-swingx: no rollover highlight for disabled component
      * 
      */
+    @Test
     public void testRolloverDisabledComponent() {
         ComponentAdapter adapter = createComponentAdapter(allColored, true);
         // rollover and adapter at 0, 0
@@ -413,7 +540,8 @@ public class HighlightPredicateTest extends InteractiveTestCase {
      * test the BIG_DECIMAL_NEGATIVE predicate.
      *
      */
-    public void testNegative() {
+    @Test
+    public void testBigDecimalNegative() {
         ComponentAdapter negative = createBigDecimalComponentAdapter(new JLabel("-50.00"));
         assertTrue(HighlightPredicate.BIG_DECIMAL_NEGATIVE.isHighlighted(negative.getComponent(), negative));
         ComponentAdapter positive = createBigDecimalComponentAdapter(new JLabel("50.00"));
@@ -426,10 +554,30 @@ public class HighlightPredicateTest extends InteractiveTestCase {
     }
 
 //---------------- special predicates
+    /**
+     * test doc'ed behaviour
+     */
+    @Test
+    public void testRowGroupConstructor() {
+        try {
+            new RowGroupHighlightPredicate(0);
+            fail("RowGroupHighlight must throw IllegalArgumentException for lines < 1");
+        } catch (IllegalArgumentException ex) {
+            // expected behaviour
+        } 
+    }
+    
+    @Test
+    public void testRowGroupProperty() {
+        int lines = 5;
+        RowGroupHighlightPredicate predicate = new RowGroupHighlightPredicate(5);
+        assertEquals(lines, predicate.getLinesPerGroup());
+    }
     
     /**
      * test equals predicate with null value.
      */
+    @Test
     public void testEqualsNull() {
         HighlightPredicate predicate = new EqualsHighlightPredicate();
         allColored.setText(null);
@@ -446,6 +594,7 @@ public class HighlightPredicateTest extends InteractiveTestCase {
      * test equals predicate with not null value.
      *
      */
+    @Test
     public void testEqualsNotNull() {
         HighlightPredicate predicate = new EqualsHighlightPredicate(allColored
                 .getText());
@@ -455,6 +604,36 @@ public class HighlightPredicateTest extends InteractiveTestCase {
         assertFalse(predicate.isHighlighted(allColored, adapter));
     }
     
+    /**
+     * test equals predicate with not null value.
+     *
+     */
+    @Test
+    public void testEqualProperty() {
+        Object text = new Object();
+        EqualsHighlightPredicate predicate = new EqualsHighlightPredicate(text);
+        assertEquals(text, predicate.getCompareValue());
+    }
+    
+    @Test
+    public void testColumnProperty() {
+        int[] columns = new int[] {2, 7};
+        ColumnHighlightPredicate predicate = new ColumnHighlightPredicate(columns);
+        Integer[] output = predicate.getColumns();
+        assertEquals(columns.length, output.length);
+        for (int i = 0; i < output.length; i++) {
+            assertEquals(columns[i], output[i].intValue());
+        }
+    }
+
+    @Test
+    public void testColumnEmptyProperty() {
+        ColumnHighlightPredicate predicate = new ColumnHighlightPredicate();
+        Integer[] output = predicate.getColumns();
+        assertEquals("output must be empty array", 0, output.length);
+    }
+
+    @Test
     public void testColumn() {
         HighlightPredicate predicate = new ColumnHighlightPredicate(1);
         ComponentAdapter adapter = createComponentAdapter(allColored, false);
@@ -463,18 +642,87 @@ public class HighlightPredicateTest extends InteractiveTestCase {
         assertTrue("column 1 must be highlighted", predicate.isHighlighted(allColored, adapter));
     }
 
+
+    @Test
+    public void testDepthProperty() {
+        int[] columns = new int[] {2, 7};
+        DepthHighlightPredicate predicate = new DepthHighlightPredicate(columns);
+        Integer[] output = predicate.getDepths();
+        assertEquals(columns.length, output.length);
+        for (int i = 0; i < output.length; i++) {
+            assertEquals(columns[i], output[i].intValue());
+        }
+    }
+
+    @Test
+    public void testDepthEmptyProperty() {
+        DepthHighlightPredicate predicate = new DepthHighlightPredicate();
+        Integer[] output = predicate.getDepths();
+        assertEquals("output must be empty array", 0, output.length);
+    }
+
+    @Test
+    public void testIdentifierProperty() {
+        Object[] identifiers = new Object[] { "one", "two" };
+        IdentifierHighlightPredicate predicate = new IdentifierHighlightPredicate(identifiers);
+        Object[] output = predicate.getIdentifiers();
+        assertEquals(identifiers.length, output.length);
+        for (int i = 0; i < output.length; i++) {
+            assertEquals(identifiers[i], output[i]);
+        }
+    }
+
+    @Test
+    public void testIdentifierEmptyProperty() {
+        IdentifierHighlightPredicate predicate = new IdentifierHighlightPredicate();
+        Object[] output = predicate.getIdentifiers();
+        assertEquals("output must be empty array", 0, output.length);
+    }
+
+    @Test
     public void testIdentifierDefault() {
         HighlightPredicate predicate = new IdentifierHighlightPredicate(ComponentAdapter.DEFAULT_COLUMN_IDENTIFIER);
         ComponentAdapter adapter = createComponentAdapter(allColored, false);
         assertTrue("default (single) column must be highlighted", predicate.isHighlighted(allColored, adapter));
     }
 
+    @Test
     public void testIdentifierFalse() {
         HighlightPredicate predicate = new IdentifierHighlightPredicate("unknown");
         ComponentAdapter adapter = createComponentAdapter(allColored, false);
         assertFalse("unknown identifier must not highlight", predicate.isHighlighted(allColored, adapter));
     }
     
+    @Test
+    public void testTypeProperty() {
+        Class<?> clazz = String.class;
+        TypeHighlightPredicate predicate = new TypeHighlightPredicate(clazz);
+        assertEquals(clazz, predicate.getType());
+    }
+    
+    @Test
+    public void testTypeExact() {
+        HighlightPredicate predicate = new TypeHighlightPredicate(String.class);
+        ComponentAdapter adapter = createComponentAdapter(allColored, false);
+        assertTrue("string class must be highlighted", predicate.isHighlighted(allColored, adapter));
+    }
+
+    @Test
+    public void testTypeSubclass() {
+        HighlightPredicate predicate = new TypeHighlightPredicate();
+        ComponentAdapter adapter = createComponentAdapter(allColored, false);
+        assertTrue("string class must be highlighted", predicate.isHighlighted(allColored, adapter));
+    }
+
+    @Test
+    public void testTypeFalse() {
+        HighlightPredicate predicate = new TypeHighlightPredicate(Integer.class);
+        ComponentAdapter adapter = createComponentAdapter(allColored, false);
+        assertFalse("string class must be highlighted", predicate.isHighlighted(allColored, adapter));
+    }
+    
+// ------ stand-alone predicates    
+    @Test
     public void testPattern() {
         // start with "t"
         Pattern pattern = Pattern.compile("^t", 0);
@@ -486,13 +734,69 @@ public class HighlightPredicateTest extends InteractiveTestCase {
                   predicate.isHighlighted(allColored, adapter));
     }
     
+    @Test
+    public void testPatternWithString() {
+        // start with "t"
+        String regex = "^t";
+        int testColumn = 0;
+        int decorateColumn = 0;
+        PatternPredicate predicate = new PatternPredicate(regex, testColumn, decorateColumn);
+        Pattern pattern = Pattern.compile(regex);
+        assertEquals(pattern.pattern(), predicate.getPattern().pattern());
+        ComponentAdapter adapter = createComponentAdapter(allColored, true);
+        assertEquals("predicate must have same result as matcher", pattern.matcher(allColored.getText()).find(), 
+                  predicate.isHighlighted(allColored, adapter));
+    }
+    
+    @Test
+    public void testPatternTwoParamConstructorWithString() {
+        // start with "t"
+        String regex = "^t";
+        int testColumn = 0;
+        HighlightPredicate predicate = new PatternPredicate(regex, testColumn);
+        Pattern pattern = Pattern.compile(regex);
+        ComponentAdapter adapter = createComponentAdapter(allColored, true);
+        assertEquals("predicate must have same result as matcher", pattern.matcher(allColored.getText()).find(), 
+                  predicate.isHighlighted(allColored, adapter));
+    }
+ 
+    @Test
+    public void testSearchHighlightConstructorOne() {
+        Pattern pattern = Pattern.compile("^t");
+        SearchPredicate predicate = new SearchPredicate(pattern);
+        assertEquals(pattern, predicate.getPattern());
+        assertEquals(SearchPredicate.ALL, predicate.getHighlightColumn());
+        assertEquals(SearchPredicate.ALL, predicate.getHighlightRow());
+    }
+
+    @Test
+    public void testSearchHighlightConstructorTwo() {
+        Pattern pattern = Pattern.compile("^t");
+        int column = 10;
+        SearchPredicate predicate = new SearchPredicate(pattern, column);
+        assertEquals(pattern, predicate.getPattern());
+        assertEquals(column, predicate.getHighlightColumn());
+        assertEquals(SearchPredicate.ALL, predicate.getHighlightRow());
+    }
+    
+    @Test
+    public void testSearchHighlightConstructorFull() {
+        Pattern pattern = Pattern.compile("^t");
+        int row = 5;
+        int column = 10;
+        SearchPredicate predicate = new SearchPredicate(pattern, row, column);
+        assertEquals(pattern, predicate.getPattern());
+        assertEquals(column, predicate.getHighlightColumn());
+        assertEquals(row, predicate.getHighlightRow());
+    }
     /**
      * test match in all cells.
      *
      */
+    @Test
     public void testSearchHighlightAllMatches() {
         // start with "t"
-        Pattern pattern = Pattern.compile("^t", 0);
+        Pattern pattern = Pattern.compile("^t");
         HighlightPredicate predicate = new SearchPredicate(pattern);
         ComponentAdapter adapter = createComponentAdapter(allColored, false);
         assertEquals("predicate must have same result as matcher", pattern.matcher(allColored.getText()).find(), 
@@ -507,9 +811,10 @@ public class HighlightPredicateTest extends InteractiveTestCase {
      * test match limited by column.
      *
      */
+    @Test
     public void testSearchHighlightColumn() {
         // start with "t"
-        Pattern pattern = Pattern.compile("^t", 0);
+        Pattern pattern = Pattern.compile("^t");
         int column = 2;
         HighlightPredicate predicate = new SearchPredicate(pattern, column);
         ComponentAdapter adapter = createComponentAdapter(allColored, false);
@@ -524,11 +829,12 @@ public class HighlightPredicateTest extends InteractiveTestCase {
      * test match limited by row.
      *
      */
+    @Test
     public void testSearchHighlightRow() {
         // start with "t"
-        Pattern pattern = Pattern.compile("^t", 0);
+        Pattern pattern = Pattern.compile("^t");
         int row = 2;
-        HighlightPredicate predicate = new SearchPredicate(pattern, row, -1);
+        HighlightPredicate predicate = new SearchPredicate(pattern, row, SearchPredicate.ALL);
         ComponentAdapter adapter = createComponentAdapter(allColored, false);
         assertFalse("predicate must not match", 
                   predicate.isHighlighted(allColored, adapter));
@@ -541,9 +847,10 @@ public class HighlightPredicateTest extends InteractiveTestCase {
      * test match limited by row and column.
      *
      */
+    @Test
     public void testSearchHighlightRowAndColumn() {
         // start with "t"
-        Pattern pattern = Pattern.compile("^t", 0);
+        Pattern pattern = Pattern.compile("^t");
         int row = 2;
         int column = 2;
         HighlightPredicate predicate = new SearchPredicate(pattern, row, column);
@@ -555,14 +862,100 @@ public class HighlightPredicateTest extends InteractiveTestCase {
         assertTrue("predicate must match", 
                 predicate.isHighlighted(allColored, adapter));
     }
+    
+    /**
+     * test match in all cells using regex constructor.
+     *
+     */
+    @Test
+    public void testSearchHighlightAllMatchesWithString() {
+        // start with "t"
+        String regex = "^t";
+        HighlightPredicate predicate = new SearchPredicate(regex);
+        Pattern pattern = Pattern.compile(regex);
+        ComponentAdapter adapter = createComponentAdapter(allColored, false);
+        assertEquals("predicate must have same result as matcher", pattern.matcher(allColored.getText()).find(), 
+                  predicate.isHighlighted(allColored, adapter));
+        adapter.row = 5;
+        adapter.column = 10;
+        assertEquals("predicate must have same result as matcher", pattern.matcher(allColored.getText()).find(), 
+                predicate.isHighlighted(allColored, adapter));
+    }
+    
+    /**
+     * test match limited by column using regex constructor.
+     *
+     */
+    @Test
+    public void testSearchHighlightColumnWithString() {
+        // start with "t"
+        String regex = "^t";
+        int column = 2;
+        HighlightPredicate predicate = new SearchPredicate(regex, column);
+        ComponentAdapter adapter = createComponentAdapter(allColored, false);
+        assertFalse("predicate must not match", 
+                  predicate.isHighlighted(allColored, adapter));
+        adapter.column = column;
+        assertTrue("predicate must match", 
+                predicate.isHighlighted(allColored, adapter));
+    }
+    
+    /**
+     * test match limited by row using regex constructor.
+     *
+     */
+    @Test
+    public void testSearchHighlightRowWithString() {
+        // start with "t"
+        String regex = "^t";
+        int row = 2;
+        HighlightPredicate predicate = new SearchPredicate(regex, row, SearchPredicate.ALL);
+        ComponentAdapter adapter = createComponentAdapter(allColored, false);
+        assertFalse("predicate must not match", 
+                  predicate.isHighlighted(allColored, adapter));
+        adapter.row = row;
+        assertTrue("predicate must match", 
+                predicate.isHighlighted(allColored, adapter));
+    }
+
+    @Test
+    public void testSearchHighlightNullString() {
+        // start with "t"
+        String regex = null;
+        HighlightPredicate predicate = new SearchPredicate(regex);
+        ComponentAdapter adapter = createComponentAdapter(allColored, false);
+        assertEquals("null regex must be no match", false, 
+                  predicate.isHighlighted(allColored, adapter));
+    }
+    
+    @Test
+    public void testSearchHighlightEmptyString() {
+        // start with "t"
+        String regex = "";
+        HighlightPredicate predicate = new SearchPredicate(regex);
+        ComponentAdapter adapter = createComponentAdapter(allColored, false);
+        assertEquals("empty regex must be no match", false, 
+                  predicate.isHighlighted(allColored, adapter));
+    }
+    
+    @Test
+    public void testSearchHighlightNullPattern() {
+        Pattern pattern = null;
+        HighlightPredicate predicate = new SearchPredicate(pattern);
+        ComponentAdapter adapter = createComponentAdapter(allColored, false);
+        assertEquals("null pattern must be no match", false, 
+                  predicate.isHighlighted(allColored, adapter));
+    }
+    
+    
     // --------------------- factory methods
     /**
      * Creates and returns a ComponentAdapter on the given 
      * label with the specified selection state and non-editable.
      * 
-     * @param label
-     * @param selected
-     * @return
+     * @param label the adapter's component
+     * @param selected the adapter's selected property
+     * @return a ComponentAdapter of the label with the given properties.
      */
     protected ComponentAdapter createComponentAdapter(final JLabel label, final boolean selected) {
         return createComponentAdapter(label, selected, false);
@@ -571,12 +964,12 @@ public class HighlightPredicateTest extends InteractiveTestCase {
     /**
      * Creates and returns a ComponentAdapter on the given 
      * label with the specified selection and editable state. IsLeaf returns
-     * the same value as selected.
+     * the same value as selected. HasFocus returns selected && editable.
      * 
-     * @param label
-     * @param selected
-     * @param editable
-     * @return
+     * @param label the adapter's component
+     * @param selected the adapter's selected property
+     * @param editable the adapter's editable property
+     * @return a ComponentAdapter of the label with the given properties.
      */
     protected ComponentAdapter createComponentAdapter(final JLabel label,
             final boolean selected, final boolean editable) {
@@ -598,12 +991,6 @@ public class HighlightPredicateTest extends InteractiveTestCase {
                 return getValueAt(row, column);
             }
 
-            @Override
-            public void setValueAt(Object aValue, int row, int column) {
-                // not implemented
-                
-            }
-
             @Override
             public boolean isCellEditable(int row, int column) {
                 return isEditable();
@@ -611,7 +998,7 @@ public class HighlightPredicateTest extends InteractiveTestCase {
 
             @Override
             public boolean hasFocus() {
-                return false;
+                return isSelected() && isEditable();
             }
             
             @Override
@@ -635,10 +1022,6 @@ public class HighlightPredicateTest extends InteractiveTestCase {
                 return null;
             }
 
-            @Override
-            public String getColumnIdentifier(int columnIndex) {
-                return null;
-            }
             
         };
         return adapter;
@@ -669,12 +1052,6 @@ public class HighlightPredicateTest extends InteractiveTestCase {
                 return getValueAt(row, column);
             }
 
-            @Override
-            public void setValueAt(Object aValue, int row, int column) {
-                // TODO Auto-generated method stub
-                
-            }
-
             @Override
             public boolean isCellEditable(int row, int column) {
                 // TODO Auto-generated method stub
@@ -702,10 +1079,6 @@ public class HighlightPredicateTest extends InteractiveTestCase {
                 return null;
             }
 
-            @Override
-            public String getColumnIdentifier(int columnIndex) {
-                return null;
-            }
             
         };
         return adapter;
