@@ -1,5 +1,5 @@
 /*
- * $Id: HighlighterTest.java,v 1.42 2008/10/11 20:42:31 rah003 Exp $
+ * $Id: HighlighterTest.java 3473 2009-08-27 13:17:10Z kleopatra $
  *
  * Copyright 2004 Sun Microsystems, Inc., 4150 Network Circle,
  * Santa Clara, California 95054, U.S.A. All rights reserved.
@@ -21,8 +21,6 @@ import javax.swing.border.Border;
 import javax.swing.border.CompoundBorder;
 import javax.swing.plaf.ColorUIResource;
 
-import junit.framework.TestCase;
-
 import org.jdesktop.swingx.InteractiveTestCase;
 import org.jdesktop.swingx.decorator.HighlighterFactory.UIColorHighlighter;
 import org.jdesktop.swingx.painter.AbstractAreaPainter;
@@ -36,9 +34,6 @@ import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.junit.runners.JUnit4;
-import org.junit.Test;
-import org.junit.Before;
-import org.junit.After;
 
 
 /**
@@ -105,7 +100,7 @@ public class HighlighterTest extends InteractiveTestCase {
         PainterHighlighter hl = new PainterHighlighter();
         assertEquals(HighlightPredicate.ALWAYS, hl.getHighlightPredicate());
         assertNull(hl.getPainter());
-        Painter mattePainter = new MattePainter();
+        Painter<?> mattePainter = new MattePainter();
         PainterHighlighter withPainter = new PainterHighlighter(mattePainter);
         assertEquals(HighlightPredicate.ALWAYS, withPainter.getHighlightPredicate());
         assertEquals(mattePainter, withPainter.getPainter());
@@ -173,7 +168,7 @@ public class HighlighterTest extends InteractiveTestCase {
             @Override
             protected Component doHighlight(Component component,
                     ComponentAdapter adapter) {
-                ((AbstractAreaPainter) getPainter()).setFillPaint(Color.BLUE);
+                ((AbstractAreaPainter<?>) getPainter()).setFillPaint(Color.BLUE);
                 return super.doHighlight(component, adapter);
             }
             
@@ -767,12 +762,6 @@ public class HighlighterTest extends InteractiveTestCase {
                 return getValueAt(row, column);
             }
 
-            @Override
-            public void setValueAt(Object aValue, int row, int column) {
-                // TODO Auto-generated method stub
-                
-            }
-
             @Override
             public boolean isCellEditable(int row, int column) {
                 // TODO Auto-generated method stub
@@ -843,13 +832,6 @@ public class HighlighterTest extends InteractiveTestCase {
                 // TODO Auto-generated method stub
                 return false;
             }
-
-            @Override
-            public void setValueAt(Object value, int row, int column) {
-                // TODO Auto-generated method stub
-                
-            }
-            
         };
         return adapter;
     }
