@@ -1,5 +1,5 @@
 /*
- * $Id: HighlighterClientVisualCheck.java,v 1.29 2008/12/23 18:12:38 kschaefe Exp $
+ * $Id: HighlighterClientVisualCheck.java 3537 2009-10-13 12:45:24Z kleopatra $
  *
  * Copyright 2006 Sun Microsystems, Inc., 4150 Network Circle,
  * Santa Clara, California 95054, U.S.A. All rights reserved.
@@ -45,6 +45,7 @@ import javax.swing.JFrame;
 import javax.swing.JLabel;
 import javax.swing.JScrollPane;
 import javax.swing.ListModel;
+import javax.swing.UIManager;
 import javax.swing.table.TableModel;
 
 import org.jdesktop.swingx.InteractiveTestCase;
@@ -52,6 +53,7 @@ import org.jdesktop.swingx.JXFrame;
 import org.jdesktop.swingx.JXList;
 import org.jdesktop.swingx.JXSearchPanel;
 import org.jdesktop.swingx.JXTable;
+import org.jdesktop.swingx.JXTree;
 import org.jdesktop.swingx.JXTreeTable;
 import org.jdesktop.swingx.decorator.AbstractHighlighter;
 import org.jdesktop.swingx.decorator.BorderHighlighter;
@@ -82,18 +84,22 @@ public class HighlighterClientVisualCheck extends InteractiveTestCase {
     
     
     public static void main(String args[]) {
+//        UIManager.put("Nimbus.keepAlternateRowColor", Boolean.TRUE);
 //      setSystemLF(true);
       HighlighterClientVisualCheck test = new HighlighterClientVisualCheck();
       try {
+//          setLookAndFeel("Nimbus");
          test.runInteractiveTests();
-//         test.runInteractiveTests(".*Tool.*");
+//         test.runInteractiveTests(".*Striping.*");
 //         test.runInteractiveTests("interactive.*Search.*");
+//         test.runInteractiveTests("interactive.*BorderHighlighter");
       } catch (Exception e) {
           System.err.println("exception when executing interactive tests:");
           e.printStackTrace();
       }
   }
 
+    
     /**
      * Show variants of border Highlighters.
      *
@@ -114,6 +120,20 @@ public class HighlighterClientVisualCheck extends InteractiveTestCase {
         table.setHighlighters(outer, inner, replace);
         showWithScrollingInFrame(table, "Border Highlighters");
     }
+    
+    /**
+     * Show variants of border Highlighters.
+     *
+     */
+    public void interactiveTreeBorderHighlighter() {
+        JXTree tree = new JXTree();
+        tree.expandAll();
+        tree.setVisibleRowCount(tree.getRowCount());
+        // need SwingX highlighter
+        tree.setCellRenderer(new DefaultTreeRenderer());
+        tree.setHighlighters(new BorderHighlighter(BorderFactory.createLineBorder(Color.GREEN, 1)));
+        showWithScrollingInFrame(tree, "Border Highlighters");
+    }
 
     /**
      * Multiple Highlighters (shown as example in Javapolis 2007).
@@ -331,9 +351,9 @@ public class HighlighterClientVisualCheck extends InteractiveTestCase {
      */
     public static class ValueMappedHighlightPredicate implements HighlightPredicate {
 
-        private List values;
+        private List<?> values;
         private int testColumn;
-        public ValueMappedHighlightPredicate(List values, int testColumn) {
+        public ValueMappedHighlightPredicate(List<?> values, int testColumn) {
             this.values = values;
             this.testColumn = testColumn;
         }
@@ -669,6 +689,40 @@ public class HighlighterClientVisualCheck extends InteractiveTestCase {
     
 
 //--------------------- factory    
+    /**
+     * Simple ui-striping.
+     *
+     */
+    public void interactiveTreeTableSimpleStripingUI() {
+        JXTreeTable table = new JXTreeTable(new FileSystemModel());
+        table.setVisibleRowCount(table.getRowCount() + 3);
+        table.addHighlighter(HighlighterFactory.createSimpleStriping());
+        showWithScrollingInFrame(table, "Simple ui striping");
+    }
+    
+    /**
+     * shows the effect of a simple striping highlighter on a 
+     * colored table.
+     *
+     */
+    public void interactiveTreeTableSimpleStriping() {
+        JXTreeTable table = new JXTreeTable(new FileSystemModel());
+        table.setVisibleRowCount(table.getRowCount() + 3);
+        table.setBackground(new Color(0xC0FFC0));
+        table.addHighlighter(HighlighterFactory.createSimpleStriping());
+        showWithScrollingInFrame(table, "Simple gray striping");
+    }
+    /**
+     * Simple ui-striping.
+     *
+     */
+    public void interactiveSimpleStripingUI() {
+        JXTable table = new JXTable(tableModel);
+        table.setVisibleRowCount(table.getRowCount() + 3);
+        table.addHighlighter(HighlighterFactory.createSimpleStriping());
+        showWithScrollingInFrame(table, "Simple ui striping");
+    }
+
     /**
      * shows the effect of a simple striping highlighter on a 
      * colored table.
@@ -677,8 +731,8 @@ public class HighlighterClientVisualCheck extends InteractiveTestCase {
     public void interactiveSimpleStriping() {
         JXTable table = new JXTable(tableModel);
         table.setVisibleRowCount(table.getRowCount() + 3);
-        table.setBackground(Color.YELLOW);
-        table.addHighlighter(HighlighterFactory.createSimpleStriping(Color.LIGHT_GRAY));
+        table.setBackground(new Color(0xC0FFC0));
+        table.addHighlighter(HighlighterFactory.createSimpleStriping());
         showWithScrollingInFrame(table, "Simple gray striping");
     }
 
