@@ -1,5 +1,5 @@
 /*
- * $Id: PainterVisualCheck.java,v 1.37 2008/08/26 09:35:43 kleopatra Exp $
+ * $Id: PainterVisualCheck.java 3513 2009-09-22 11:18:09Z kleopatra $
  *
  * Copyright 2006 Sun Microsystems, Inc., 4150 Network Circle,
  * Santa Clara, California 95054, U.S.A. All rights reserved.
@@ -136,8 +136,8 @@ public class PainterVisualCheck extends InteractiveTestCase {
     public void interactiveRolloverPainter() {
         TableModel model = new AncientSwingTeam();
         JXTable table = new JXTable(model);
-        MattePainter<JComponent> matte = new MattePainter<JComponent>(getTransparentColor(Color.RED, 80));
-        RelativePainter painter = new RelativePainter<JComponent>(matte);
+        MattePainter matte = new MattePainter(getTransparentColor(Color.RED, 80));
+        RelativePainter<?> painter = new RelativePainter<Object>(matte);
         painter.setYFactor(0.2);
         painter.setVerticalAlignment(VerticalAlignment.BOTTOM);
         Highlighter hl = new PainterHighlighter(HighlightPredicate.ROLLOVER_ROW, painter);
@@ -173,8 +173,8 @@ public class PainterVisualCheck extends InteractiveTestCase {
     public void interactiveTableBarHighlight() {
         TableModel model = new AncientSwingTeam();
         JXTable table = new JXTable(model);
-        MattePainter<JComponent> p =  new MattePainter<JComponent>(getTransparentColor(Color.BLUE, 125));
-        RelativePainter relativePainter = new RelativePainter<JComponent>(p);
+        MattePainter p =  new MattePainter(getTransparentColor(Color.BLUE, 125));
+        RelativePainter<?> relativePainter = new RelativePainter<Object>(p);
         relativePainter.setXFactor(.5);
         Highlighter hl = new PainterHighlighter(createComponentTextBasedPredicate("y"), 
                 relativePainter);
@@ -198,7 +198,7 @@ public class PainterVisualCheck extends InteractiveTestCase {
         JXList list = new JXList();
         Highlighter highlighter = HighlighterFactory.createSimpleStriping(HighlighterFactory.LINE_PRINTER);
         table.addHighlighter(highlighter);
-        Painter gradient = createGradientPainter(Color.YELLOW, .7f, true);
+        Painter<?> gradient = createGradientPainter(Color.YELLOW, .7f, true);
         list.setHighlighters(highlighter, new PainterHighlighter(gradient));
         // quick-fill and hook to table columns' visibility state
         configureList(list, table, false);
@@ -241,7 +241,7 @@ public class PainterVisualCheck extends InteractiveTestCase {
      * @param transparent
      * @return
      */
-    protected Painter createGradientPainter(Color startColor, float end,
+    protected Painter<?> createGradientPainter(Color startColor, float end,
             boolean transparent) {
         startColor = getTransparentColor(startColor, transparent ? 125 : 254);
         Color endColor = getTransparentColor(Color.WHITE, 0);
@@ -251,11 +251,11 @@ public class PainterVisualCheck extends InteractiveTestCase {
                    new Point2D.Double(1000, 0),
                    endColor);
 
-        MattePainter<JComponent> painter = new MattePainter<JComponent>(paint);
+        MattePainter painter = new MattePainter(paint);
         painter.setPaintStretched(true);
         // not entirely successful - the relative stretching is on
         // top of a .5 stretched gradient in matte
-        RelativePainter wrapper = new RelativePainter<JComponent>(painter);
+        RelativePainter<?> wrapper = new RelativePainter<Object>(painter);
         wrapper.setXFactor(end);
         return wrapper;
     }
@@ -325,9 +325,10 @@ public class PainterVisualCheck extends InteractiveTestCase {
     public void interactiveAnimatedIconPainterHighlight()  {
         TableModel model = new AncientSwingTeam();
         JXTable table = new JXTable(model);
-        ImagePainter<Component> imagePainter = new ImagePainter<Component>(XTestUtils.loadDefaultImage("green-orb.png"));
+        table.getColumn(1).setCellRenderer(new DefaultTableRenderer(new HyperlinkProvider()));
+        ImagePainter imagePainter = new ImagePainter(XTestUtils.loadDefaultImage("green-orb.png"));
         imagePainter.setHorizontalAlignment(HorizontalAlignment.RIGHT);
-        final RelativePainter painter = new RelativePainter<Component>(imagePainter);
+        final RelativePainter<?> painter = new RelativePainter<Component>(imagePainter);
         PainterHighlighter iconHighlighter = new PainterHighlighter();
         iconHighlighter.setHighlightPredicate(HighlightPredicate.ROLLOVER_ROW);
         iconHighlighter.setPainter(painter);
@@ -399,9 +400,9 @@ public class PainterVisualCheck extends InteractiveTestCase {
         tree.setRolloverEnabled(true);
         
         tree.setCellRenderer(new DefaultTreeRenderer(StringValues.FILE_NAME));
-        ImagePainter<Component> imagePainter = new ImagePainter<Component>(XTestUtils.loadDefaultImage("green-orb.png"));
+        ImagePainter imagePainter = new ImagePainter(XTestUtils.loadDefaultImage("green-orb.png"));
         imagePainter.setHorizontalAlignment(HorizontalAlignment.RIGHT);
-        final RelativePainter painter = new RelativePainter<Component>(imagePainter);
+        final RelativePainter<?> painter = new RelativePainter<Component>(imagePainter);
         PainterHighlighter iconHighlighter = new PainterHighlighter();
         iconHighlighter.setHighlightPredicate(HighlightPredicate.ROLLOVER_ROW);
         iconHighlighter.setPainter(painter);
@@ -495,7 +496,7 @@ public class PainterVisualCheck extends InteractiveTestCase {
     /**
      * Simple Painter for subimage.
      */
-    public static class SubImagePainter extends AbstractPainter {
+    public static class SubImagePainter extends AbstractPainter<Object> {
         BufferedImage image;
         Rectangle imageClip;
 
@@ -592,7 +593,7 @@ public class PainterVisualCheck extends InteractiveTestCase {
     
     public static class RelativePainter<T> extends AbstractLayoutPainter<T> {
 
-        private Painter<T> painter;
+        private Painter<? super T> painter;
         private double xFactor;
         private double yFactor;
 
@@ -600,17 +601,17 @@ public class PainterVisualCheck extends InteractiveTestCase {
             this(null);
         }
         
-        public void setPainter(Painter<T> painter) {
+        public void setPainter(Painter<? super T> painter) {
             Object old = getPainter();
             this.painter = painter;
             firePropertyChange("painter", old, getPainter());
         }
         
-        public Painter<T> getPainter() {
+        public Painter<? super T> getPainter() {
             return painter;
         }
         
-        public RelativePainter(Painter<T> delegate) {
+        public RelativePainter(Painter<? super T> delegate) {
             this.painter = delegate;
         }
         
@@ -746,7 +747,7 @@ public class PainterVisualCheck extends InteractiveTestCase {
                         isRightAligned ? endColor : startColor, 
                         new Point2D.Double(100, 0), 
                         isRightAligned ? startColor : endColor);
-                MattePainter<JComponent> painter = new MattePainter<JComponent>(paint);
+                MattePainter painter = new MattePainter(paint);
                 painter.setPaintStretched(true);
                 getPainter().setPainter(painter);
             } 
