@@ -1,5 +1,5 @@
 /*
- * $Id: RendererIssues.java,v 1.30 2008/12/23 18:12:37 kschaefe Exp $
+ * $Id: RendererIssues.java 3488 2009-09-05 10:31:16Z kleopatra $
  *
  * Copyright 2006 Sun Microsystems, Inc., 4150 Network Circle,
  * Santa Clara, California 95054, U.S.A. All rights reserved.
@@ -48,7 +48,6 @@ import javax.swing.JLabel;
 import javax.swing.JList;
 import javax.swing.JRadioButton;
 import javax.swing.JTextField;
-import javax.swing.JTree;
 import javax.swing.ListCellRenderer;
 import javax.swing.ListModel;
 import javax.swing.LookAndFeel;
@@ -480,7 +479,6 @@ public class RendererIssues extends InteractiveTestCase {
                 }
                 return null;
             }
-
             private int getVisibleWidth() {
                 int width = getVisibleRect().width;
                 int indent =  (((BasicTreeUI)getUI()).getLeftChildIndent() + ((BasicTreeUI)getUI()).getRightChildIndent());
@@ -516,7 +514,7 @@ public class RendererIssues extends InteractiveTestCase {
         MattePainter painter = new MattePainter(Color.YELLOW);
         Highlighter hl = new PainterHighlighter(HighlightPredicate.ROLLOVER_ROW, painter);
         tree.addHighlighter(hl);
-        ComponentProvider provider = new NormalButtonProvider(StringValues.TO_STRING, JLabel.LEADING);
+        ComponentProvider<?> provider = new NormalButtonProvider(StringValues.TO_STRING, JLabel.LEADING);
         tree.setCellRenderer(new DefaultTreeRenderer(provider));
         tree.setRolloverEnabled(true);
         showWithScrollingInFrame(tree, "Fancy..");
@@ -613,7 +611,7 @@ public class RendererIssues extends InteractiveTestCase {
      * 
      */
     public void testNodeTypeIcons() {
-       CellContext<JTree> context = new TreeCellContext();
+       TreeCellContext context = new TreeCellContext();
        context.installContext(null, "dummy", -1, -1, false, false, false, true);
        final Icon custom = XTestUtils.loadDefaultIcon();
        IconValue iv = new IconValue() {
