@@ -1,5 +1,5 @@
 /*
- * $Id: RendererVisualCheck.java,v 1.56 2008/12/23 18:12:37 kschaefe Exp $
+ * $Id: RendererVisualCheck.java 3473 2009-08-27 13:17:10Z kleopatra $
  *
  * Copyright 2006 Sun Microsystems, Inc., 4150 Network Circle,
  * Santa Clara, California 95054, U.S.A. All rights reserved.
@@ -46,6 +46,7 @@ import java.util.Calendar;
 import java.util.Collections;
 import java.util.Date;
 import java.util.List;
+import java.util.logging.Logger;
 
 import javax.swing.AbstractAction;
 import javax.swing.AbstractListModel;
@@ -69,6 +70,10 @@ import javax.swing.ListModel;
 import javax.swing.SwingConstants;
 import javax.swing.UIDefaults;
 import javax.swing.border.Border;
+import javax.swing.event.ChangeEvent;
+import javax.swing.event.ListSelectionEvent;
+import javax.swing.event.TableColumnModelEvent;
+import javax.swing.event.TableColumnModelListener;
 import javax.swing.filechooser.FileSystemView;
 import javax.swing.table.AbstractTableModel;
 import javax.swing.table.DefaultTableModel;
@@ -116,13 +121,17 @@ import org.jdesktop.test.AncientSwingTeam;
  * @author Jeanette Winzenburg
  */
 public class RendererVisualCheck extends InteractiveTestCase {
+    @SuppressWarnings("unused")
+    private static final Logger LOG = Logger
+            .getLogger(RendererVisualCheck.class.getName());
+    
     public static void main(String[] args) {
         setSystemLF(true);
         RendererVisualCheck test = new RendererVisualCheck();
         try {
 //            test.runInteractiveTests();
-          test.runInteractiveTests(".*CustomIcons.*");
-//          test.runInteractiveTests(".*XLabel.*");
+//          test.runInteractiveTests(".*CustomIcons.*");
+          test.runInteractiveTests(".*TextArea.*");
 //          test.runInteractiveTests(".*Color.*");
 //          test.runInteractiveTests("interactive.*ColumnControl.*");
         } catch (Exception e) {
@@ -406,29 +415,88 @@ public class RendererVisualCheck extends InteractiveTestCase {
     }
     
     /**
-     * Quick example of using a JTextArea as rendering component.
+     * Quick example of using a JTextArea as rendering component and 
+     * dynamically adjust table row height to max pref height of the
+     * cells in a row.
      *
      */
-    public void interactiveTextAreaRenderer() {
-        DefaultTableModel model = new DefaultTableModel(0, 1);
-        model.addRow(new String[] {"some really, maybe really really long text -  "
-                + "wrappit .... where needed "});
-        model.addRow(new String[] {"another really, maybe really really long text -  "
-                + "with nothing but junk. wrappit .... where needed"});
+    public void interactiveTextAreaRendererTable() {
+        DefaultTableModel model = new DefaultTableModel(0, 2);
+        model.addRow(new String[]{"some really, maybe really really long text -  "
+                + "wrappit .... where needed ", "some really, maybe really really long text -  " +
+                "wrappit .... where needed "});
+        model.addRow(new String[]{"another really, maybe really really long text -  "
+                + "with nothing but junk. wrappit .... where needed", "some really, maybe really really long text -  " +
+                "wrappit .... where needed "});
+
+
         JXTable table = new JXTable(model);
-        table.setVisibleRowCount(4);
-        table.setVisibleColumnCount(2);
         table.setColumnControlVisible(true);
-        table.getColumnExt(0).setCellRenderer(new DefaultTableRenderer(new TextAreaProvider()));
-        table.addHighlighter(
-                HighlighterFactory.createAlternateStriping());
-        // simulate some means to get a reasonable rowheight
-        table.packColumn(0, -1);
-        JTextArea textArea = (JTextArea) table.prepareRenderer(table.getCellRenderer(0, 0), 0, 0);
-        table.setRowHeight(textArea.getPreferredSize().height);
+        table.setDefaultRenderer(Object.class, new DefaultTableRenderer(new TextAreaProvider()));
+        table.addHighlighter(HighlighterFactory.createSimpleStriping());
+        installDynamicRowHeights(table);
         showWithScrollingInFrame(table, "textArea as rendering comp");
     }
+
+    /**
+     * Configures the table to allow individual row heights based on rendering components
+     * pref size and inits the sizes. Installs an extended column model listener to 
+     * update the rowHeights on changes to the column widths.
+     * 
+     * NOTE: this is not complete - real-world methods must 
+     * - listen to the TableModel to update the rowHeight 
+     * - listen to table's property changes for its Table/ColumnModel to 
+     *   re-wire the appropriate listeners.
+     * - be prepared to handle performance problems for large models
+     * 
+     * @param table
+     */
+    private void installDynamicRowHeights(final JXTable table) {
+        updateRowHeight(table);
+        TableColumnModelListener columnListener = new TableColumnModelListener() {
+
+            public void columnAdded(TableColumnModelEvent e) {
+                updateRowHeight(table);
+            }
+
+            public void columnMarginChanged(ChangeEvent e) {
+                // here we rely on an implementation detail of DefaultTableColumnModel:
+                // which fires a marginChanged is column widths are changed
+                updateRowHeight(table);
+            }
+
+            public void columnMoved(TableColumnModelEvent e) {
+            }
+
+            public void columnRemoved(TableColumnModelEvent e) {
+                updateRowHeight(table);
+            }
+
+            public void columnSelectionChanged(ListSelectionEvent e) {
+            }
+            
+        };
+        table.getColumnModel().addColumnModelListener(columnListener);
+    }
     
+    /**
+     * Sets per-row rowHeight based on the rendering component's preferred height.
+     * 
+     * @param table
+     */
+    private void updateRowHeight(final JXTable table) {
+        for (int row = 0; row < table.getRowCount(); row++) {
+            int rowHeight = 0;
+            for (int column = 0; column < table.getColumnCount(); column++) {
+                Component comp = table.prepareRenderer(table
+                        .getCellRenderer(row, column), row, column);
+                rowHeight = Math.max(rowHeight,
+                        comp.getPreferredSize().height);
+            }
+            table.setRowHeight(row, rowHeight); 
+        }
+    }
+
     /**
      * use a JTextArea as rendering component.
      */
@@ -436,11 +504,37 @@ public class RendererVisualCheck extends InteractiveTestCase {
 
         @Override
         protected void configureState(CellContext context) {
+            int columnWidth = getPreferredAreaWidth(context);
+            if (columnWidth > 0) {
+                rendererComponent.setSize(columnWidth, Short.MAX_VALUE);
+            }
+        }
+
+        /**
+         * @param context
+         * @return
+         */
+        private int getPreferredAreaWidth(CellContext context) {
+            if (context.getComponent() instanceof JXTable) {
+                JXTable table = (JXTable) context.getComponent();
+                return table.getColumn(context.getColumn()).getWidth();
+            }
+            if (context.getComponent() instanceof JTree) {
+                // TODO: implement width and depth based initial width
+            }
+            if (context.getComponent() != null) {
+                // pending: accont for insets
+                // doesn't really work for a JList in a scrollPane
+                // need to track..
+                return context.getComponent().getWidth();
+            }
+            // comp is null - not much we can do
+            return -1;
         }
 
         @Override
         protected JTextArea createRendererComponent() {
-            JTextArea area = new JTextArea(3, 20);
+            JTextArea area = new JTextArea();
             area.setLineWrap(true);
             area.setWrapStyleWord(true);
             area.setOpaque(true);
@@ -453,7 +547,7 @@ public class RendererVisualCheck extends InteractiveTestCase {
         }
         
     }
-
+ 
     /**
      * Quick example of using a JXLabel as rendering component.
      * Looks funny .. wrapping jumps?
@@ -577,7 +671,7 @@ public class RendererVisualCheck extends InteractiveTestCase {
      */
     private TableModel createTableModelWithDefaultTypes() {
         String[] names = {"Object", "Number", "Double", "Date", "ImageIcon", "Boolean"};
-        final Class[] types = {Object.class, Number.class, Double.class, Date.class, ImageIcon.class, Boolean.class};
+        final Class<?>[] types = {Object.class, Number.class, Double.class, Date.class, ImageIcon.class, Boolean.class};
         DefaultTableModel model = new DefaultTableModel(names, 0) {
 
             @Override
@@ -816,7 +910,7 @@ public class RendererVisualCheck extends InteractiveTestCase {
     public void interactiveTestTableLinkRenderer() {
         EditorPaneLinkVisitor visitor = new EditorPaneLinkVisitor();
         JXTable table = new JXTable(createModelWithLinks());
-        LinkModelAction action = new LinkModelAction<LinkModel>(visitor);
+        LinkModelAction<LinkModel> action = new LinkModelAction<LinkModel>(visitor);
         ComponentProvider<JXHyperlink> controller = new HyperlinkProvider(action, LinkModel.class);
         table.setDefaultRenderer(LinkModel.class, new DefaultTableRenderer(controller));
         JFrame frame = wrapWithScrollingInFrame(table, visitor.getOutputComponent(), "show link renderer in table");
@@ -832,7 +926,7 @@ public class RendererVisualCheck extends InteractiveTestCase {
         EditorPaneLinkVisitor visitor = new EditorPaneLinkVisitor();
         JXList list = new JXList(createListModelWithLinks(20));
         list.setRolloverEnabled(true);
-        LinkModelAction action = new LinkModelAction(visitor);
+        LinkModelAction<LinkModel> action = new LinkModelAction<LinkModel>(visitor);
         ComponentProvider<JXHyperlink> context = new HyperlinkProvider(action, LinkModel.class);
         list.setCellRenderer(new DefaultListRenderer(context));
         JFrame frame = wrapWithScrollingInFrame(list, visitor.getOutputComponent(), "show link renderer in list");
@@ -848,7 +942,7 @@ public class RendererVisualCheck extends InteractiveTestCase {
         EditorPaneLinkVisitor visitor = new EditorPaneLinkVisitor();
         JXTree tree = new JXTree(createTreeModelWithLinks(20));
         tree.setRolloverEnabled(true);
-        LinkModelAction action = new LinkModelAction(visitor);
+        LinkModelAction<LinkModel> action = new LinkModelAction<LinkModel>(visitor);
         ComponentProvider<JXHyperlink> context = new HyperlinkProvider(action, LinkModel.class);
         tree.setCellRenderer(new DefaultTreeRenderer(new WrappingProvider(context)));
         JFrame frame = wrapWithScrollingInFrame(tree, visitor.getOutputComponent(), "show link renderer in list");
@@ -1111,7 +1205,7 @@ public class RendererVisualCheck extends InteractiveTestCase {
         xtable.setDefaultRenderer(Color.class, new DefaultTableRenderer(controller));
         TreeModel model = createTreeColorModel();
         JTree tree = new JTree(model);
-        ComponentProvider wrapper = new WrappingProvider(controller); //;createColorRenderingLabelController());
+        ComponentProvider<?> wrapper = new WrappingProvider(controller); //;createColorRenderingLabelController());
         TreeCellRenderer renderer = new DefaultTreeRenderer(wrapper);
         tree.setCellRenderer(renderer);
         JXFrame frame = wrapWithScrollingInFrame(xtable, tree, "JXTable/JXTree: Custom color renderer - sharing the component controller");
@@ -1393,7 +1487,7 @@ public class RendererVisualCheck extends InteractiveTestCase {
      * @since 1.1.1
      */
     public static PropertyDescriptor getPropertyDescriptor(
-        Class beanClass,
+        Class<?> beanClass,
         String propertyName)
         throws IntrospectionException {
 
