@@ -1,5 +1,5 @@
 /*
- * $Id: PropertyChangeReport.java,v 1.4 2008/06/13 14:41:39 kleopatra Exp $
+ * $Id: PropertyChangeReport.java 3414 2009-07-27 10:09:28Z kleopatra $
  *
  * Copyright 2004 Sun Microsystems, Inc., 4150 Network Circle,
  * Santa Clara, California 95054, U.S.A. All rights reserved.
@@ -8,6 +8,7 @@
 
 package org.jdesktop.test;
 
+import java.awt.Component;
 import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
 import java.util.Collections;
@@ -31,8 +32,21 @@ public class PropertyChangeReport implements PropertyChangeListener {
     protected List<PropertyChangeEvent> events = Collections.synchronizedList(new LinkedList<PropertyChangeEvent>());
     protected Map<String, PropertyChangeEvent> eventMap = Collections.synchronizedMap(new HashMap<String, PropertyChangeEvent>());
     
+    public PropertyChangeReport() {
+        this(null);
+    }
+    
+    /**
+     * @param component
+     */
+    public PropertyChangeReport(Component component) {
+        if(component != null) {
+            component.addPropertyChangeListener(this);
+        }
+    }
 //------------------------ implement PropertyChangeListener
     
+
     public void propertyChange(PropertyChangeEvent evt) {
         events.add(0, evt);
         if (evt.getPropertyName() != null) {
@@ -158,5 +172,4 @@ public class PropertyChangeReport implements PropertyChangeListener {
     }
 
 
-
 }
